// A utility function that returns true if a string contains only
// whitespace characters.
function isblank(s)
{
	for(var i = 0; i < s.length; i++) {
		var c = s.charAt(i);
		if ((c != ' ') && (c != '\n') && (c != '\t')) return false;
	}
	return true;
}

function getRadioValue( radiogroup ) 
{
	// radiogroup is the array of radio objects
	for( var i=0; i<radiogroup.length; i++ ) {
		if( radiogroup[i].checked )
			return radiogroup[i].value; // return selected option's value.
	}
	return "none"; // none were selected.
}

function getFieldName( f )
{
	return f.FriendlyName != null ? f.FriendlyName : f.name;
}

// This is the function that performs form verification. It will be invoked
// from the onSubmit() event handler. The handler should return whatever
// value this function returns.
function verify(frm)
{
	var f = document.forms[0] || frm.target;
	var msg;
	var empty_fields = "";
	var errors = "";
	var focusfield = null;
		
	var warn_focusfield = null;
	var empty_warn_count = 0;
	
	// Loop through the elements of the form, looking for all
	// text and textarea elements that have a "required=true" property
	// defined. Then, check for fields that are empty and make a list of them.
	// Also, if any of these elements have a "min" or a "max" property defined,
	// then verify that they are numbers and that they are in the right range.
	// Put together error messages for fields that are wrong.
	for(var i = 0; i < f.elements.length; i++) {
		var e = f.elements[i];
		if ( (e.type == "text") || (e.type == "textarea") || (e.type == "password") ||
				(e.type == "select-one") ) {
			if( e.required ) {
				// first check if the field is empty
				if ((e.value == null) || (e.value == "") || (isblank(e.value))) {
					if( e.required == "warn" ) { 
						// merely a warn field
						empty_warn_count++;
						warn_focusfield = warn_focusfield ? warn_focusfield : e;
					} else {
						// a required field
						empty_fields += "\n " + getFieldName(e);
						// mark this field to receive focus if we haven't already picked a field.
						focusfield = focusfield ? focusfield : e;
					}

					continue;
				}

				// Check for minimum length requirements
				if( e.minlength && e.value.length < e.minlength ) {
					errorText = "- $FieldTooShort$\n";
					errorText = errorText.replace('{0}', getFieldName(e));
					errorText = errorText.replace('{1}', e.minlength);
					errors += errorText;

					// mark this field to receive focus if we haven't already picked a field.
					focusfield = focusfield ? focusfield : e;
				}
			}
			
			if( e.maxlength && e.value.length > e.maxlength ) {
				errorText = "- $FieldTooLong$\n";
				errorText = errorText.replace('{0}', getFieldName(e));
				errorText = errorText.replace('{1}', e.maxlength);
				errors += errorText;

				// mark this field to receive focus if we haven't already picked a field.
				focusfield = focusfield ? focusfield : e;
			}

			// Now check for fields that are supposed to be numeric.
			if (e.numeric || (e.min != null) || (e.max != null) ) {
				var v = parseFloat(e.value);
				if (isNaN(e.value) || ((e.min != null) && (v < e.min)) ||
									((e.max != null) && (v > e.max))) {
					errorText = "- ";
					if (e.min != null && e.max != null)
						errorText += "$OutOfRangeBothBounds$";
					else if (e.min != null && e.max == null)
						errorText += "$OutOfRangeLowerBound$";
					else if (e.min == null && e.max != null)
						errorText += "$OutOfRangeUpperBound$";
					else //if (isNaN(e.value))
						errorText += "$FieldIsANumber$";
					errorText = errorText.replace('{0}', getFieldName(e));
					errorText = errorText.replace('{1}', e.min);
					errorText = errorText.replace('{2}', e.max);
					errors += errorText + "\n";

					// mark this field to receive focus if we haven't already picked a field.
					focusfield = focusfield ? focusfield : e;
				}
			}
			
			// Now check for fields that are supposed to be dates.
			if (e.calendardate) {
				var v = Date.parse(e.value);
				if( (e.required && isblank(e.value)) || (!isblank(e.value) && isNaN(v)) ) {
					// Either the field is required and is blank
					// or it is not blank but is an invalid date.
					errorText = "- $InvalidDateFormat$\n";
					errorText = errorText.replace('{0}', getFieldName(e));
					errors += errorText;
					
					// mark this field to receive focus if we haven't already picked a field.
					focusfield = focusfield ? focusfield : e;
				}
			}
		}

		if (e.required && (e.type == "radio") && f.elements[e.name][0] == e ) {
			// check to see if any radio option has been selected
			if (getRadioValue( f.elements[e.name] ) == "none") {
				if( e.required == "warn" ) {
					// merely a warn field
					empty_warn_count++;
					warn_focusfield = warn_focusfield ? warn_focusfield : e;
				} else {
					// Actually a required field
					empty_fields += "\n " + getFieldName(e);

					// mark this field to receive focus if we haven't already picked a field.
					focusfield = focusfield ? focusfield : e;
				}
			}
		}
	}
	
	// Now, if there were any errors, display the messages, and
	// return false to prevent the form from being submitted.
	// Otherwise return true.
	if (!empty_warn_count && !empty_fields && !errors) return true;

	msg = "";
	if( errors || empty_fields ) { // don't display this msg if only optional fields were left blank
		msg += "$InputErrorPreText$\n";
		msg += "__________________________________________________\n\n";
	}
	
	if (empty_fields) {
		msg += "- $RequiredFieldsEmpty$"
		+ empty_fields + "\n";
		if (errors) msg += "\n";
	} else if( !errors ) { // only provide warning once required fields are filled.
		if(empty_warn_count) {
			msg += "- $LeftAnswersBlank$\n".replace('{0}', empty_warn_count);
		}
	}
	msg += errors;

	if(warn_focusfield) warn_focusfield.focus();
	if(focusfield) focusfield.focus(); // required overrides warn fields
	
	// If the user provided answers that were invalid, force him to go back.
	// But if the user merely left answers blank, allow him to continue if he wants.
	if( errors || empty_fields ) { // If there were invalid answers or required blanks
		msg += "__________________________________________________\n\n";
		msg += "$InputErrorPostText$";
		alert(msg);
		return false;
	}
	else { // just empty, optional fields.
		var msgconfirm = "\n$MoveOnWithWarningsPrompt$";
		return confirm(msg + msgconfirm);
	}
}

function dotNetSubmit(source, arguments) {
	arguments.IsValid = verify(source);
}

function domSubmit(source) {
	return verify(source);
}

function domSubmit(source, arguments) {
	return verify(source);
}
// This next line intentionally left as a comment with no line break at the end
// 