<?xml version="1.0" encoding="UTF-8" ?>
<xsl:stylesheet version="1.0" 
				xmlns:xsl="http://www.w3.org/1999/XSL/Transform" 
				xmlns="http://www.w3.org/1999/xhtml" 
				xmlns:ddi="http://www.icpsr.umich.edu/DDI"
				xmlns:ExsltStrings="http://fhss.byu.edu/exslt/strings"
				exclude-result-prefixes="ExsltStrings xsl ddi">

<xsl:include href="project://NAssess.Core/Engines/Evaluation/xslt.html/global.xslt"/>

<xsl:variable name="TextInputToTextAreaThreshold" select="'55'"/>

	<!-- STANDARD -->
	<xsl:template match="ddi:var[ddi:varFormat/@type='character' or ddi:varFormat/@type='numeric'][not(ddi:varFormat/@category='date')][not(ddi:catgry)]">
		<xsl:variable name="var" select="."/>
		
		<span>
			<xsl:attribute name="id"><xsl:value-of select="@name"/></xsl:attribute>			
			<xsl:attribute name="class">
				<xsl:choose>
					<xsl:when test="ddi:varFormat/@category = 'other'">
						<xsl:text>VarOther</xsl:text>
					</xsl:when>
					<xsl:otherwise>
						<xsl:text>Var</xsl:text>
					</xsl:otherwise>
				</xsl:choose>
			</xsl:attribute>
			
			<xsl:call-template name="preQTxt">
				<xsl:with-param name="var" select="."/>
			</xsl:call-template>
			<xsl:call-template name="QTxt">
				<xsl:with-param name="var" select="."/>
			</xsl:call-template>

			<xsl:choose>
				<xsl:when test="ddi:location/@width > $TextInputToTextAreaThreshold"> <!-- textarea rather than one-line text box -->
					<textarea>
						<xsl:attribute name="name"><xsl:value-of select="@name"/></xsl:attribute>
						<xsl:attribute name="cols"><xsl:value-of select="$TextInputToTextAreaThreshold"/></xsl:attribute>
						<xsl:attribute name="rows"><xsl:value-of select="round(ddi:location/@width div $TextInputToTextAreaThreshold)+1"/></xsl:attribute>
						
						<xsl:value-of select="$data/@*[name() = $var/@name]"/>
						<!-- almost empty text node prevents collapsing into a 
						     self-closing textarea tag, which some browsers choke on. -->
						<xsl:text> </xsl:text>
					</textarea>
				</xsl:when>
				<xsl:otherwise> <!-- standard text box is appropriate -->
					<input class="FreeResponse">
						<xsl:attribute name="name"><xsl:value-of select="@name"/></xsl:attribute>
						<xsl:if test="ddi:location/@width">
							<xsl:attribute name="maxlength"><xsl:value-of select="ddi:location/@width"/></xsl:attribute>
							<xsl:attribute name="size"><xsl:value-of select="ddi:location/@width"/></xsl:attribute>
						</xsl:if>
						<xsl:if test="ddi:varFormat/@type='numeric'">
							<xsl:attribute name="numeric">true</xsl:attribute>
						</xsl:if>
						
						<xsl:attribute name="value">
							<xsl:value-of select="$data/@*[name() = $var/@name]"/>
						</xsl:attribute>
					</input>
				</xsl:otherwise>
			</xsl:choose>
			
			<xsl:if test="ddi:valrng/ddi:range/@min or ddi:valrng/ddi:range/@max">
				<span class="AllowedValues">
					<xsl:text>(</xsl:text>
					<xsl:if test="ddi:valrng/ddi:range/@min">
						<xsl:value-of select="ddi:valrng/ddi:range/@min"/>
					</xsl:if>
					<xsl:text>-</xsl:text>
					<xsl:if test="ddi:valrng/ddi:range/@max">
						<xsl:value-of select="ddi:valrng/ddi:range/@max"/>
					</xsl:if>
					<xsl:text>)</xsl:text>
				</span>
			</xsl:if>
			
			<xsl:call-template name="postQTxt">
				<xsl:with-param name="var" select="."/>
			</xsl:call-template>
		</span>
	</xsl:template>

	<!-- Validation -->
	<xsl:template match="ddi:var[ddi:varFormat/@type='character' or ddi:varFormat/@type='numeric'][not(ddi:varFormat/@category='date')][not(ddi:catgry)][not(ddi:varFormat/@category='other')]"
				  mode="validation">
		<!-- Don't prompt user for more input when the field is of the optional "other" type (that selection is done in template match)-->

		<!-- Do validation stuff appropriate for fields of all free response, non-other types -->
		f.elements["<xsl:value-of select="@name"/>"].required = "warn";
		<xsl:if test="string-length(normalize-space(ddi:labl)) &gt; 0">
			f.elements["<xsl:value-of select="@name"/>"].FriendlyName = "<xsl:value-of select='ExsltStrings:escapeQuotes(normalize-space(ddi:labl))'/>";
		</xsl:if>
		<xsl:if test="ddi:location/@width">
			f.elements["<xsl:value-of select="@name"/>"].maxlength = <xsl:value-of select="ddi:location/@width"/>;
		</xsl:if>

		<!-- Perform validation specific to numeric fields -->
		<xsl:if test="ddi:varFormat/@type='numeric' and not(ddi:varFormat/@category='date') and not(ddi:catgry)">
			f.elements["<xsl:value-of select="@name"/>"].numeric = true;
			<xsl:if test="ddi:valrng/ddi:range/@min">
				f.elements["<xsl:value-of select="@name"/>"].min = <xsl:value-of select="ddi:valrng/ddi:range/@min"/>;
			</xsl:if>
			<xsl:if test="ddi:valrng/ddi:range/@max">
				f.elements["<xsl:value-of select="@name"/>"].max = <xsl:value-of select="ddi:valrng/ddi:range/@max"/>;
			</xsl:if>
		</xsl:if>
		
	</xsl:template>

</xsl:stylesheet>
