<?xml version="1.0" encoding="UTF-8" ?>
<xsl:stylesheet version="1.0" 
				xmlns:xsl="http://www.w3.org/1999/XSL/Transform" 
				xmlns="http://www.w3.org/1999/xhtml" 
				xmlns:ddi="http://www.icpsr.umich.edu/DDI"
				xmlns:ExsltStrings="http://fhss.byu.edu/exslt/strings"
				xmlns:stdext="http://nassess.byu.edu/rendering/evaluation/StandardHtml"
				exclude-result-prefixes="ExsltStrings xsl ddi stdext">

<xsl:include href="project://NAssess.Core/Engines/Evaluation/xslt.html/global.xslt"/>

	<!-- The standard group template -->
	<xsl:template match="ddi:varGrp">
		<!-- Check to make sure that this group should be rendered -->
		<xsl:if test="stdext:IsVarGrpActiveBasedOnData(.)">
			<div>
				<xsl:attribute name="id">
					<xsl:value-of select="@ID"/>
				</xsl:attribute>
				<xsl:attribute name="class">
					<xsl:value-of select="@type"/>
				</xsl:attribute>

				<!-- If this varGrp has a <ddi:txt> tag, send it out to describe this group that is about to start -->
				<xsl:if test="ddi:txt">
					<div class="SectionText">
						<xsl:apply-templates select="ddi:txt/* | ddi:txt/text()"/>
					</div>
				</xsl:if>
				
				<!-- If there are any groups defined, render them first -->
				<xsl:apply-templates select="@varGrp"/>
				<!-- If there are any variables defined in this group, render them next -->
				<xsl:apply-templates select="@var"/>
			</div>
		</xsl:if>
	</xsl:template>
	
	<xsl:template match="ddi:varGrp/@var">
		<xsl:variable name="thisVarGrp" select=".."/>
		<!-- This is a variable list -->
		<xsl:variable name="vars" select="ExsltStrings:tokenize(.)"/>
		<xsl:for-each select="$vars">
			<xsl:apply-templates select="$root/ddi:codeBook/ddi:dataDscr/ddi:var[@ID=current()/text()]"/>
		</xsl:for-each>
	</xsl:template>
	
	<!-- Validation recursion -->
	<xsl:template match="ddi:varGrp" mode="validation">
		<!-- Check to make sure that this group should be rendered -->
		<xsl:if test="stdext:IsVarGrpActiveBasedOnData(.)">
			<!-- If there are any groups defined, render them first -->
			<xsl:apply-templates select="@varGrp" mode="validation"/>
			<!-- If there are any variables defined in this group, render them next -->
			<xsl:apply-templates select="@var" mode="validation"/>
		</xsl:if>
	</xsl:template>

	<xsl:template match="ddi:varGrp/@var" mode="validation">
		<xsl:variable name="thisVarGrp" select=".."/>
		<!-- This is a variable list -->
		<xsl:variable name="vars" select="ExsltStrings:tokenize(.)"/>
		<xsl:for-each select="$vars">
			<xsl:apply-templates select="$root/ddi:codeBook/ddi:dataDscr/ddi:var[@ID=current()/text()]"
								 mode="validation">
				<xsl:with-param name="inGrid" select="$thisVarGrp/@type='grid'"/>
			</xsl:apply-templates>
		</xsl:for-each>
	</xsl:template>

	<!-- hidden hint field recursion -->
	<xsl:template match="ddi:varGrp" mode="hintField">
		<!-- Check to make sure that this group should be rendered -->
		<xsl:if test="stdext:IsVarGrpActiveBasedOnData(.)">
			<!-- If there are any groups defined, render them first -->
			<xsl:apply-templates select="@varGrp" mode="hintField"/>
			<!-- If there are any variables defined in this group, render them next -->
			<xsl:apply-templates select="@var" mode="hintField"/>
		</xsl:if>
	</xsl:template>

	<xsl:template match="ddi:varGrp/@var" mode="hintField">
		<xsl:variable name="thisVarGrp" select=".."/>
		<!-- This is a variable list -->
		<xsl:variable name="vars" select="ExsltStrings:tokenize(.)"/>
		<xsl:for-each select="$vars">
			<xsl:if test="text() != ''"> <!-- skip the trailing space at the end of these strings -->
				<xsl:apply-templates select="$root/ddi:codeBook/ddi:dataDscr/ddi:var[@ID=current()/text()]"
									mode="hintField"/>
				<!-- we used to only add this space when "position()!=last()", but that didn't work since
					when this varGrp is not the last in the list, you end up with something like this:
					"v1 v2 v3v4 v5 v6" -->
				<xsl:text> </xsl:text>
			</xsl:if>
		</xsl:for-each>
	</xsl:template>
	
</xsl:stylesheet>
