<?xml version="1.0" encoding="UTF-8" ?>
<xsl:stylesheet version="1.0" 
				xmlns:xsl="http://www.w3.org/1999/XSL/Transform" 
				xmlns="http://www.w3.org/1999/xhtml" 
				xmlns:ddi="http://www.icpsr.umich.edu/DDI"
				xmlns:ExsltStrings="http://fhss.byu.edu/exslt/strings"
				xmlns:stdext="http://nassess.byu.edu/rendering/evaluation/StandardHtml"
				exclude-result-prefixes="ExsltStrings xsl ddi stdext">

<xsl:include href="project://NAssess.Core/Engines/Evaluation/xslt.html/global.xslt"/>
<xsl:param name="GroupSelectOneOptionsOnLeft"/>
<xsl:param name="varGrpSelectOneOptionFrequency" select="'4'"/>

	<!-- The grid group template -->
	<xsl:template match="ddi:varGrp[@type='grid']">
		<!-- Check to make sure that this group should be rendered -->
		<xsl:if test="stdext:IsVarGrpActiveBasedOnData(.)">

		<!-- These next three variables turn in useful for stacked grids.  
			 Stacked grids are grids with more than one question per row.  -->
		<xsl:variable name="varGrpIDs" select="ExsltStrings:tokenize(@varGrp)"/>
		<!-- the "| current()[not(..." bit at the end of this next statement makes $primaryGrp
			 good for more than just in stacked grid situations. -->
		<xsl:variable name="primaryGrp" select="$root/ddi:codeBook/ddi:dataDscr/ddi:varGrp[@ID=$varGrpIDs[1]] | current()[not(@varGrp)]"/>
		<xsl:variable name="otherGrps" select="$root/ddi:codeBook/ddi:dataDscr/ddi:varGrp[@ID=$varGrpIDs[position() &gt; 1]]"/>

		<div class='SelectOneGroup'>
			<xsl:attribute name="id">
				<xsl:value-of select="@ID"/>
			</xsl:attribute>

			<span class="preQText">
				<!-- This is a variable list -->
				<xsl:variable name="vars" select="ExsltStrings:tokenize($primaryGrp/@var)"/>
				<xsl:variable name="firstvar" select="$root/ddi:codeBook/ddi:dataDscr/ddi:var[@ID=$vars[1]]"/>
				<xsl:apply-templates select="$firstvar/ddi:qstn/ddi:preQTxt/* | $firstvar/ddi:qstn/ddi:preQTxt/text()"/>
				<!-- This was when we didn't require at least the first question to have its pre-question text set
					 <xsl:apply-templates select="ddi:txt"/> -->
			</span>
			<table cellspacing='0'>
				<xsl:choose>
					<xsl:when test="@var"> <!-- normal grid -->
						<xsl:apply-templates select="@var"/>
					</xsl:when>
					<xsl:when test="@varGrp"> <!-- stacked grid -->
						<xsl:apply-templates select="$primaryGrp/@var">
							<xsl:with-param name="stackedVarGrps" select="$otherGrps"/>
						</xsl:apply-templates>
					</xsl:when>
				</xsl:choose>
			</table>
		</div>

		</xsl:if>
	</xsl:template>

	<xsl:template match="ddi:varGrp[@type='grid']/@var">
		<xsl:param name="stackedVarGrps"/>
		
		<xsl:variable name="thisVarGrp" select=".."/>
		<!-- This is a variable list -->
		<xsl:variable name="vars" select="ExsltStrings:tokenize(.)"/>
		<xsl:variable name="firstvar" select="$root/ddi:codeBook/ddi:dataDscr/ddi:var[@ID=$vars[1]]"/>
		<xsl:for-each select="$vars">
			<xsl:variable name="position" select='position()'/>
			<!-- Output response choices when appropriate -->
			<xsl:if test="$position mod $varGrpSelectOneOptionFrequency = 1">
				<!-- Maybe put up a first heading row to label each of the stacked grid sections -->
				<xsl:if test="$stackedVarGrps and $thisVarGrp/ddi:txt">
					<tr>
						<!-- if options are to appear on the right of the question text,
							   then stick in an empty cell to offset the options correctly. -->
						<xsl:if test="not($GroupSelectOneOptionsOnLeft)">
							<td/>
						</xsl:if>
						<!-- put up the categorical text above the response labels -->
						
						<th class="StackedLabel"> <!-- we used to combine this into the for-each below, but a bug kept it from showing up lower in the grid -->
							<xsl:attribute name="colspan">
								<xsl:value-of select="count($firstvar/ddi:catgry/ddi:labl)"/>
							</xsl:attribute>
							<xsl:attribute name="id">
								<xsl:text>stacked</xsl:text>
								<xsl:value-of select='$thisVarGrp/@ID'/>
							</xsl:attribute>
							<xsl:value-of select="normalize-space($thisVarGrp/ddi:txt)"/>
						</th>
						<xsl:for-each select="$stackedVarGrps">
							<th class="StackedLabel">
								<xsl:attribute name="colspan">
									<xsl:variable name="guestVarID" select="ExsltStrings:tokenize(@var)[1]"/>
									<xsl:variable name="guestVar" select="$root/ddi:codeBook/ddi:dataDscr/ddi:var[@ID=$guestVarID]"/>
									<xsl:value-of select="count($guestVar/ddi:catgry/ddi:labl)"/>
								</xsl:attribute>
								<xsl:attribute name="id">
									<xsl:text>stacked</xsl:text>
									<xsl:value-of select='@ID'/>
								</xsl:attribute>
								<xsl:value-of select="normalize-space(ddi:txt)"/>
							</th>
						</xsl:for-each>
					</tr>
				</xsl:if>
				
				<!-- put up the standard heading row -->
				<tr>
					<!-- if options are to appear on the right of the question text,
						then stick in an empty cell to offset the options correctly. -->
					<xsl:if test="not($GroupSelectOneOptionsOnLeft)">
						<td/>
					</xsl:if>

					<xsl:for-each select="$firstvar/ddi:catgry/ddi:labl">
						<th class="ValueLabel"><xsl:apply-templates select="*|text()"/></th>
					</xsl:for-each>
					<xsl:if test="$stackedVarGrps">
						<xsl:for-each select="$stackedVarGrps">
							<xsl:variable name="guestVarID" select="ExsltStrings:tokenize(@var)[1]"/>
							<xsl:variable name="guestVar" select="$root/ddi:codeBook/ddi:dataDscr/ddi:var[@ID=$guestVarID]"/>
							<span>
								<xsl:attribute name="id">
									<xsl:value-of select="$guestVarID"/>
								</xsl:attribute>
								<xsl:for-each select="$guestVar/ddi:catgry/ddi:labl">
									<th class="ValueLabel"><xsl:apply-templates select="*|text()"/></th>
								</xsl:for-each>
							</span>
						</xsl:for-each>
					</xsl:if>
<!--					
					<th class="preQText">
						On the very first row, output the grid text, if available
						(COMMENTED because we do this before this template gets called now.)
						<xsl:if test="position() = 1">
							<xsl:value-of select="$thisVarGrp/ddi:txt"/>
						</xsl:if>
					</th>
-->
				</tr>
			</xsl:if>					
			
			<!-- Output actual grid variable -->
			<xsl:apply-templates 
								 select="$root/ddi:codeBook/ddi:dataDscr/ddi:var[@ID=current()/text()]"
								 mode="group">
				<xsl:with-param name="position" select="$position"/>
				<xsl:with-param name="stackedVarGrps" select="$stackedVarGrps"/>
			</xsl:apply-templates>
		</xsl:for-each>
	</xsl:template>

</xsl:stylesheet>
