<?xml version="1.0" encoding="UTF-8" ?>
<xsl:stylesheet version="1.0" 
				xmlns:xsl="http://www.w3.org/1999/XSL/Transform" 
				xmlns="http://www.w3.org/1999/xhtml" 
				xmlns:ddi="http://www.icpsr.umich.edu/DDI"
				xmlns:ExsltStrings="http://fhss.byu.edu/exslt/strings"
				xmlns:stdext="http://nassess.byu.edu/rendering/evaluation/StandardHtml"
				exclude-result-prefixes="ExsltStrings xsl ddi stdext">

<xsl:include href="project://NAssess.Core/Engines/Evaluation/xslt.html/global.xslt"/>
<xsl:param name="DropdownToRadioListThreshold" select="'75'"/>
<xsl:param name="GroupSelectOneOptionsOnLeft"/>

	<xsl:template match="ddi:var[@intrvl='discrete'][ddi:varFormat/@type='numeric'][ddi:catgry]">
		<span class="Var">
			<xsl:attribute name="id"><xsl:value-of select="@name"/></xsl:attribute>
			
			<xsl:call-template name="preQTxt">
				<xsl:with-param name="var" select="."/>
			</xsl:call-template>
			<xsl:call-template name="QTxt">
				<xsl:with-param name="var" select="."/>
			</xsl:call-template>
	
			<xsl:variable name="longestValueLabel" select="stdext:MaxStringLength(ddi:catgry/ddi:labl)"/>
			<xsl:choose>
				<xsl:when test="stdext:MaxStringLength(ddi:catgry/ddi:labl) &gt; $DropdownToRadioListThreshold">
					<xsl:apply-templates select="." mode="radio"/>
				</xsl:when>
				<xsl:otherwise>
					<xsl:apply-templates select="." mode="dropdown"/>
				</xsl:otherwise>
			</xsl:choose>
			
			<!-- If this variable has an Other response label, with an associated
			text field, render that text field here. -->
			<xsl:variable name="otherVar" select="../ddi:var[@ID=current()/ddi:codInstr][ddi:varFormat/@category='other']"/>
			<xsl:if test="$otherVar">
				<xsl:apply-templates select="$otherVar"/>
			</xsl:if>
			
			<xsl:call-template name="postQTxt">
				<xsl:with-param name="var" select="."/>
			</xsl:call-template>
		</span>
	</xsl:template>
	
	<!-- Dropdown style -->
	<xsl:template mode="dropdown" match="ddi:var[@intrvl='discrete'][ddi:varFormat/@type='numeric'][ddi:catgry]">
		<xsl:variable name="var" select="."/>

		<!-- Render the options -->
		<select class="SelectOneResponseText">
			<xsl:attribute name="name"><xsl:value-of select="@name"/></xsl:attribute>
			<option value="">
				<xsl:text> </xsl:text>
			</option> <!-- blank (default) option -->
			<xsl:for-each select="ddi:catgry">
				<option>
					<xsl:attribute name="value"><xsl:value-of select="normalize-space(ddi:catValu)"/></xsl:attribute>
					<xsl:if test="normalize-space(ddi:catValu) = $data/@*[name() = $var/@name]">
						<xsl:attribute name="selected">true</xsl:attribute>
					</xsl:if>
					<xsl:value-of select="normalize-space(ddi:labl)"/>
				</option>
			</xsl:for-each>
		</select>
	</xsl:template>

	<!-- Radio buttons -->
	<xsl:template mode="radio" match="ddi:var[@intrvl='discrete'][ddi:varFormat/@type='numeric'][ddi:catgry]">
		<xsl:variable name="var" select="."/>

		<!-- Render the options -->
		<table class="SelectList">
			<xsl:for-each select="ddi:catgry">
				<tr>
					<xsl:choose>
						<xsl:when test="position() mod 2 = 1">
							<xsl:attribute name="class">AlternateRow</xsl:attribute>
						</xsl:when>
						<xsl:otherwise>
							<xsl:attribute name="class">Row</xsl:attribute>
						</xsl:otherwise>
					</xsl:choose>

					<td class="input">
						<input type="radio">
							<xsl:attribute name="name"><xsl:value-of select="$var/@name"/></xsl:attribute>
							<xsl:attribute name="value"><xsl:value-of select="normalize-space(ddi:catValu)"/></xsl:attribute>
							<xsl:attribute name="id">
								<xsl:value-of select="$var/@name"/>
								<xsl:text>_</xsl:text>
								<xsl:value-of select="normalize-space(ddi:catValu)"/>
							</xsl:attribute>
							<xsl:if test="normalize-space(ddi:catValu) = $data/@*[name() = $var/@name]">
								<xsl:attribute name="checked">true</xsl:attribute>
							</xsl:if>
						</input>
					</td>
					<td class="ValueLabel">
						<label>
							<xsl:attribute name="for">
								<xsl:value-of select="$var/@name"/>
								<xsl:text>_</xsl:text>
								<xsl:value-of select="normalize-space(ddi:catValu)"/>
							</xsl:attribute>
							<xsl:apply-templates select="ddi:labl"/>
						</label>
					</td>
				</tr>
			</xsl:for-each>
			
		</table>
	</xsl:template>
	
	<!-- GRID -->
	<xsl:template mode="group" match="ddi:var[@intrvl='discrete'][ddi:varFormat/@type='numeric'][ddi:catgry]">
		<xsl:param name="position"/>
		<xsl:param name="stackedVarGrps"/>
		<xsl:variable name="var" select="."/>
		
		<tr>
			<xsl:attribute name="id"><xsl:value-of select="@name"/></xsl:attribute>
			
			<xsl:choose>
				<xsl:when test="$position mod 2 = 1">
					<xsl:attribute name="class">AlternateRow</xsl:attribute>
				</xsl:when>
				<xsl:otherwise>
					<xsl:attribute name="class">Row</xsl:attribute>
				</xsl:otherwise>
			</xsl:choose>
	
			<xsl:choose>
				<xsl:when test="$GroupSelectOneOptionsOnLeft">
					<xsl:apply-templates select="." mode="groupOptions">
						<xsl:with-param name="stackedVarGrps" select="$stackedVarGrps"/>
						<xsl:with-param name="position" select="$position"/>
					</xsl:apply-templates>
					<xsl:apply-templates select="." mode="groupQTxt"/>
				</xsl:when>
				<xsl:otherwise>
					<xsl:apply-templates select="." mode="groupQTxt"/>
					<xsl:apply-templates select="." mode="groupOptions">
						<xsl:with-param name="stackedVarGrps" select="$stackedVarGrps"/>
						<xsl:with-param name="position" select="$position"/>
					</xsl:apply-templates>
				</xsl:otherwise>
			</xsl:choose>
		</tr>
	</xsl:template>
	
	<xsl:template mode="groupOptions" match="ddi:var[@intrvl='discrete'][ddi:varFormat/@type='numeric'][ddi:catgry]">
		<xsl:param name="position"/>
		<xsl:param name="stackedVarGrps"/>
		<xsl:variable name="var" select="."/>

		<xsl:for-each select="ddi:catgry/ddi:catValu">
			<td class="input">
				<input type="radio">
					<xsl:attribute name="name"><xsl:value-of select="$var/@name"/></xsl:attribute>
					<xsl:attribute name="value"><xsl:value-of select="normalize-space(.)"/></xsl:attribute>
					<!-- Set checked if user has already checked this response -->
					<xsl:if test="normalize-space(.) = $data/@*[name() = $var/@name]">
						<xsl:attribute name="checked">true</xsl:attribute>
					</xsl:if>
				</input>
			</td>
		</xsl:for-each>
		<xsl:if test="$stackedVarGrps">
			<xsl:for-each select="$stackedVarGrps">
				<xsl:variable name="guestVarID" select="ExsltStrings:tokenize(@var)[position() = $position]"/>
				<xsl:variable name="guestVar" select="$root/ddi:codeBook/ddi:dataDscr/ddi:var[@ID=$guestVarID]"/>
				<xsl:for-each select="$guestVar/ddi:catgry/ddi:catValu">
					<td class="input">
						<input type="radio">
							<xsl:attribute name="name"><xsl:value-of select="$guestVar/@name"/></xsl:attribute>
							<xsl:attribute name="value"><xsl:value-of select="normalize-space(.)"/></xsl:attribute>
							<!-- Set checked if user has already checked this response -->
							<xsl:if test="normalize-space(.) = $data/@*[name() = $guestVar/@name]">
								<xsl:attribute name="checked">true</xsl:attribute>
							</xsl:if>
						</input>
					</td>
				</xsl:for-each>
			</xsl:for-each>
		</xsl:if>
	</xsl:template>
	<xsl:template mode="groupQTxt" match="ddi:var[@intrvl='discrete'][ddi:varFormat/@type='numeric'][ddi:catgry]">
			<th>
				<xsl:call-template name="QTxt">
					<xsl:with-param name="var" select="."/>
				</xsl:call-template>
				<!-- If there is an associated "other" box, draw it as well. -->
				<xsl:variable name="otherVar" select="../ddi:var[@ID=current()/ddi:codInstr][ddi:varFormat/@category='other']"/>
				<xsl:if test="$otherVar">
					<xsl:apply-templates select="$otherVar"/>
				</xsl:if>
			</th>
	</xsl:template>
	
	<!-- Validation -->
	<xsl:template mode="validation" match="ddi:var[@intrvl='discrete'][ddi:varFormat/@type='numeric'][ddi:catgry]">
		<xsl:param name="inGrid"/>
		<xsl:if test="string-length(normalize-space(ddi:labl)) &gt; 0">
			f.elements["<xsl:value-of select="@name"/>"].FriendlyName = "<xsl:value-of select='ExsltStrings:escapeQuotes(normalize-space(ddi:labl))'/>";
		</xsl:if>
		<xsl:choose>
			<!-- We must work some special syntax in the JavaScript for grids and other radio lists -->
			<xsl:when test="$inGrid or stdext:MaxStringLength(ddi:catgry/ddi:labl) &gt; $DropdownToRadioListThreshold">
			f.elements["<xsl:value-of select="@name"/>"][0].required = "warn";
			</xsl:when>
			<xsl:otherwise>
			f.elements["<xsl:value-of select="@name"/>"].required = "warn";
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>
</xsl:stylesheet>
