using System;
using System.IO;

namespace NAssess.Core.Engines
{
	/// <summary>
	/// Any class that implements this interface can render a report as
	/// XSL-FO (XSL Formatting Objects).
	/// </summary>
	public abstract class FORenderingEngine : RenderingEngine
	{
		#region Attributes
		public override RenderingEngine.Target RenderTarget
		{
			get
			{
				return RenderingEngine.Target.FO;
			}
		}
		/// <summary>
		/// The URL of the logo to put on the title page of the PDF.
		/// Relative to the directory specified by the ImagesWithTextDirectory attribute.
		/// </summary>
		public string LogoImageUrl;
		#endregion

		#region Operations
		public delegate void InlineFormatter(Stream foStream);
		public abstract void ToFO(Stream outStream, bool monochrome, InlineFormatter inlineFormatter);
		public virtual void ToFO(Stream outStream, bool monochrome)
		{
			ToFO(outStream, monochrome, null);
		}
		public virtual Stream ToFO(bool monochrome, InlineFormatter inlineFormatter)
		{
			// Prepare stream to store resulting FO
			MemoryStream foStream = new MemoryStream(150 * 1024); // start out at 150K

			ToFO(foStream, monochrome, inlineFormatter);

			foStream.Position = 0; // reset to start of stream
			return foStream;
		}
		public virtual Stream ToFO(bool monochrome)
		{
			return ToFO(monochrome, null);
		}
		#endregion

		#region Exceptions
		public class FORenderingException : RenderingException
		{
			public FORenderingException() { }
			public FORenderingException(string msg) : base(msg) { }
			public FORenderingException(string msg, Exception innerException) : base(msg, innerException) { }
		}
		#endregion
	}
}
