using System;
using System.Collections;
using System.Xml;
using System.Xml.XPath;
using System.Xml.Xsl;
using NAssess.Core.Engines;

namespace NAssess.Core.Engines
{
	/// <summary>
	/// Summary description for ExtensionsHtml.
	/// </summary>
	public class PlugInExtensions
	{
		protected RenderingEngine stdParser;
		protected ArrayList extensions = new ArrayList();

		public PlugInExtensions(RenderingEngine stdParser)
		{
			this.stdParser = stdParser;
		}

		public void Add(IReportExtension extensionObject)
		{
			if (extensionObject == null) throw new ArgumentNullException("extensionObject");

			// Note that this Contains check allows adding another instance
			// of the same class, which you usually do not want.
			if (!extensions.Contains(extensionObject))
			{
				extensions.Add(extensionObject);
				extensionObject.AttachTo(stdParser);
			}
		}

		public XPathNodeIterator Parse(XPathNodeIterator tagToParse)
		{
			if (tagToParse == null) throw new ArgumentNullException("tagToParse");
			// The strategy is to iterate through all of the extension objects and use
			// the first one that claims to handle this particular tag.
			while (tagToParse.MoveNext())
				foreach (IReportExtension extension in extensions)
					if (extension.CanParseTag(tagToParse.Current.LocalName))
						return extension.Parse(tagToParse.Current);
			throw new ApplicationException(string.Format(Resources.NoPluginRespondedToTag, tagToParse.Current.LocalName));
		}

	}

	public interface IReportExtension
	{
		XPathNodeIterator Parse(XPathNavigator tagToParse);
		bool CanParseTag(string tagName);
		void AttachTo(RenderingEngine stdParser);
	}
}
