<?xml version="1.0" encoding="UTF-8" ?>
<xsl:stylesheet version="1.0" 
				xmlns:fo="http://www.w3.org/1999/XSL/Format"
				xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
				xmlns:ddi="http://www.icpsr.umich.edu/DDI"
				xmlns:xhtml="http://www.w3.org/1999/xhtml" 
				xmlns:culture="http://nassess.byu.edu/culture"
				xmlns:ExsltStrings="http://fhss.byu.edu/exslt/strings"
				exclude-result-prefixes="ExsltStrings xsl ddi culture">

	<xsl:import href="project://NAssess.Core/Engines/Questionnaire/xslt/imports.xslt" />
	<xsl:import href="project://NAssess.Core/Engines/Questionnaire/xslt.fo/global.xslt" />
	<xsl:import href="project://NAssess.Core/Engines/Questionnaire/xslt.fo/titlepage.xslt" />
	<xsl:import href="project://NAssess.Core/Engines/Questionnaire/xslt.fo/introduction.xslt" />
	<xsl:import href="project://NAssess.Core/Engines/Questionnaire/xslt.fo/consent.xslt" />
	<xsl:import href="project://NAssess.Core/Engines/Questionnaire/xslt.fo/closingstatement.xslt" />
	
	<!-- IMPORTANT: Leave varGeneric.xslt the first imported transform.  Otherwise,
	 any variable output XSLTs above it will not work. -->
	<xsl:import href="project://NAssess.Core/Engines/Questionnaire/xslt.fo/varGeneric.xslt"/>
	<xsl:import href="project://NAssess.Core/Engines/Questionnaire/xslt.fo/varFreeResponse.xslt"/>
	<xsl:import href="project://NAssess.Core/Engines/Questionnaire/xslt.fo/varSelectOne.xslt"/>
	<xsl:import href="project://NAssess.Core/Engines/Questionnaire/xslt.fo/varSelectMany.xslt"/>
	<xsl:import href="project://NAssess.Core/Engines/Questionnaire/xslt.fo/varDate.xslt"/>
	<xsl:import href="project://NAssess.Core/Engines/Questionnaire/xslt.fo/varGrp.xslt"/>

	<!-- The following import(s) must fall at the END of the above list because of priority of imports requirements -->
	<xsl:import href="project://NAssess.Core/Engines/Questionnaire/xslt.fo/html2fo.xslt" />
	<xsl:import href="project://NAssess.Core/Engines/Questionnaire/xslt.fo/ddi2fo.xslt" />

	<xsl:strip-space elements="*"/>
	<xsl:output method="xml" omit-xml-declaration='yes' indent='yes'/>


	<xsl:template match="/">

		<fo:root xmlns:fo="http://www.w3.org/1999/XSL/Format" xmlns:xhtml="http://www.w3.org/1999/xhtml">
			<fo:layout-master-set>
				<fo:simple-page-master master-name="titlePage" page-width="8.5in" page-height="11in">
					<fo:region-body margin-top="0.5in" margin-bottom="1in" margin-left="0.5in" margin-right="0.5in" />
				</fo:simple-page-master>
				<fo:simple-page-master master-name="introPages" page-width="8.5in" page-height="11in">
					<fo:region-body margin-top="0.5in" margin-bottom="1in" margin-left="0.5in" margin-right="0.5in" />
					<fo:region-after region-name="contentFooter" extent="0.8in" />
				</fo:simple-page-master>
				<fo:simple-page-master master-name="contentPages" page-width="8.5in" page-height="11in">
					<fo:region-body margin-top="0.5in" margin-bottom="1in" margin-left="0.5in" margin-right="0.5in" column-count="2"/>
					<fo:region-before region-name="contentHeader" extent="0.4in" />
					<fo:region-after region-name="contentFooter" extent="0.8in" />
				</fo:simple-page-master>
				<fo:simple-page-master master-name="closingPages" page-width="8.5in" page-height="11in">
					<fo:region-body margin-top="0.5in" margin-bottom="1in" margin-left="0.5in" margin-right="0.5in" />
					<fo:region-after region-name="contentFooter" extent="0.8in" />
				</fo:simple-page-master>

				<fo:page-sequence-master master-name="firstPagesSequence">
					<fo:single-page-master-reference master-reference="titlePage" />
					<fo:repeatable-page-master-reference master-reference="introPages" />
				</fo:page-sequence-master>
			</fo:layout-master-set>

			<fo:page-sequence master-reference="firstPagesSequence" initial-page-number="1" format="i">
				<fo:static-content flow-name="contentFooter">
					<fo:block text-align="center" space-after="8pt">
						<xsl:value-of select="culture:GetResourceStringXSLT('PageNumber')"/>
						<fo:page-number />
					</fo:block>
				</fo:static-content>
				<fo:flow font-family="Times New Roman, serif" font-size="12pt" text-align="justify" text-indent="0pt" flow-name="xsl-region-body">
					<xsl:call-template name="RenderTitlePage"/>
					<xsl:call-template name="Introduction"/>
					<xsl:call-template name="Consent"/>
				</fo:flow>
			</fo:page-sequence>

			<fo:page-sequence master-reference="contentPages" initial-page-number="1" format="1">
				<fo:static-content flow-name="contentHeader">
					<fo:block display-align="after" text-align="center">
						<xsl:value-of select="$questionnaire-title"/>
					</fo:block>
				</fo:static-content>
				<fo:static-content flow-name="contentFooter">
					<fo:block text-align="center" space-after="8pt">
						<xsl:value-of select="culture:GetResourceStringXSLT('PageNumber')"/>
						<fo:page-number />
					</fo:block>
				</fo:static-content>
				<fo:flow font-family="Times New Roman, serif" font-size="{$defaultFontSize}pt" text-align="justify" text-indent="0pt" flow-name="xsl-region-body">

					<xsl:apply-templates select="ddi:codeBook/ddi:dataDscr/ddi:varGrp[@type='display']/@varGrp"/>

				</fo:flow>
			</fo:page-sequence>

			<xsl:if test="$closingStatement != ''">
				<fo:page-sequence master-reference="closingPages">
					<fo:static-content flow-name="contentFooter">
						<fo:block text-align="center" space-after="8pt">
							<xsl:value-of select="culture:GetResourceStringXSLT('PageNumber')"/>
							<fo:page-number />
						</fo:block>
					</fo:static-content>
					<fo:flow font-family="Times New Roman, serif" font-size="{$defaultFontSize}pt" text-align="justify" text-indent="0pt" flow-name="xsl-region-body">
						<xsl:call-template name="ClosingStatement"/>
					</fo:flow>
				</fo:page-sequence>
			</xsl:if>
		</fo:root>


	</xsl:template>
</xsl:stylesheet>
