<?xml version="1.0" encoding="UTF-8" ?>
<xsl:stylesheet version="1.0" 
				xmlns:fo="http://www.w3.org/1999/XSL/Format"
				xmlns:xsl="http://www.w3.org/1999/XSL/Transform" 
				xmlns="http://www.w3.org/1999/xhtml" 
				xmlns:ddi="http://www.icpsr.umich.edu/DDI"
				xmlns:ExsltStrings="http://fhss.byu.edu/exslt/strings"
				xmlns:stdext="http://nassess.byu.edu/rendering/evaluation/StandardHtml"
				exclude-result-prefixes="ExsltStrings xsl ddi stdext">

	<xsl:param name="GroupSelectOneOptionsOnLeft"/>

	<xsl:attribute-set name="SelectOneGroup">
		<xsl:attribute name="space-before.minimum">5mm</xsl:attribute>
		<xsl:attribute name="space-after.minimum">5mm</xsl:attribute>
	</xsl:attribute-set>

	<xsl:attribute-set name="ValueLabel">
		<xsl:attribute name="display-align">after</xsl:attribute>
	</xsl:attribute-set>

	<!-- The grid group template -->
	<xsl:template match="ddi:varGrp[@type='grid']">
		<!-- These next three variables turn in useful for stacked grids.  
			 Stacked grids are grids with more than one question per row.  -->
		<xsl:variable name="varGrpIDs" select="ExsltStrings:tokenize(@varGrp)"/>
		<!-- the "| current()[not(..." bit at the end of this next statement makes $primaryGrp
			 good for more than just in stacked grid situations. -->
		<xsl:variable name="primaryGrp" select="$root/ddi:dataDscr/ddi:varGrp[@ID=$varGrpIDs[1]] | current()[not(@varGrp)]"/>
		<xsl:variable name="stackedVarGrps" select="$root/ddi:dataDscr/ddi:varGrp[@ID=$varGrpIDs[position() &gt; 1]]"/>

		<fo:block xsl:use-attribute-sets='SelectOneGroup'>
			<!-- This is a variable list -->
			<xsl:variable name="vars" select="ExsltStrings:tokenize($primaryGrp/@var)"/>
			<xsl:variable name="firstvar" select="$root/ddi:dataDscr/ddi:var[@ID=$vars[1]]"/>
			<xsl:call-template name="preQTxt">
				<xsl:with-param name="var" select="$firstvar"/>
			</xsl:call-template>

			<fo:table inline-progression-dimension="100%" table-layout="fixed">
				<xsl:for-each select="$firstvar/ddi:catgry/ddi:labl">
					<fo:table-column column-number="{position()+1}" column-width="{$defaultFontSize+2}pt"/>
				</xsl:for-each>
				<fo:table-header>
					<!-- Maybe put up a first heading row to label each of the stacked grid sections -->
					<xsl:if test="$stackedVarGrps and ddi:txt">
						<fo:table-row>
							<!-- if options are to appear on the right of the question text,
							   then stick in an empty cell to offset the options correctly. -->
							<xsl:if test="not($GroupSelectOneOptionsOnLeft)">
								<fo:table-cell/>
							</xsl:if>
							<!-- put up the categorical text above the response labels -->

							<fo:table-cell>
								<!-- we used to combine this into the for-each below, but a bug kept it from showing up lower in the grid -->
								<xsl:attribute name="number-columns-spanned">
									<xsl:value-of select="count($firstvar/ddi:catgry/ddi:labl)"/>
								</xsl:attribute>
								<fo:block>
									<xsl:value-of select="normalize-space(ddi:txt)"/>
								</fo:block>
							</fo:table-cell>
							<xsl:for-each select="$stackedVarGrps">
								<fo:table-cell>
									<xsl:attribute name="number-columns-spanned">
										<xsl:variable name="guestVarID" select="ExsltStrings:tokenize(@var)[1]"/>
										<xsl:variable name="guestVar" select="$root/ddi:dataDscr/ddi:var[@ID=$guestVarID]"/>
										<xsl:value-of select="count($guestVar/ddi:catgry/ddi:labl)"/>
									</xsl:attribute>
									<fo:block>
										<xsl:value-of select="normalize-space(ddi:txt)"/>
									</fo:block>
								</fo:table-cell>
							</xsl:for-each>
						</fo:table-row>
					</xsl:if>

					<!-- put up the standard heading row -->
					<fo:table-row>
						<!-- if options are to appear on the right of the question text,
						then stick in an empty cell to offset the options correctly. -->
						<xsl:if test="not($GroupSelectOneOptionsOnLeft)">
							<fo:table-cell/>
						</xsl:if>

						<xsl:for-each select="$firstvar/ddi:catgry/ddi:labl">
							<fo:table-cell xsl:use-attribute-sets="ValueLabel">
								<fo:block-container reference-orientation="90">
									<!-- keep-together (below) is a rendering bug workaround -->
									<fo:block keep-together.within-line="always">
										<xsl:apply-templates select="*|text()"/>
									</fo:block>
								</fo:block-container>
							</fo:table-cell>
						</xsl:for-each>
						<xsl:if test="$stackedVarGrps">
							<xsl:for-each select="$stackedVarGrps">
								<xsl:variable name="guestVarID" select="ExsltStrings:tokenize(@var)[1]"/>
								<xsl:variable name="guestVar" select="$root/ddi:dataDscr/ddi:var[@ID=$guestVarID]"/>
								<xsl:for-each select="$guestVar/ddi:catgry/ddi:labl">
									<fo:table-cell xsl:use-attribute-sets="ValueLabel">
										<fo:block-container reference-orientation="90">
											<fo:block>
												<xsl:apply-templates select="*|text()"/>
											</fo:block>
										</fo:block-container>
									</fo:table-cell>
								</xsl:for-each>
							</xsl:for-each>
						</xsl:if>
					</fo:table-row>
				</fo:table-header>

				<fo:table-body>
					<xsl:choose>
						<xsl:when test="@var">
							<!-- normal grid -->
							<xsl:apply-templates select="@var"/>
						</xsl:when>
						<xsl:when test="@varGrp">
							<!-- stacked grid -->
							<xsl:apply-templates select="$primaryGrp/@var">
								<xsl:with-param name="stackedVarGrps" select="$stackedVarGrps"/>
							</xsl:apply-templates>
						</xsl:when>
					</xsl:choose>
				</fo:table-body>
			</fo:table>
		</fo:block>
	</xsl:template>

	<xsl:template match="ddi:varGrp[@type='grid']/@var">
		<xsl:param name="stackedVarGrps"/>

		<!-- This is a variable list -->
		<xsl:variable name="vars" select="ExsltStrings:tokenize(.)"/>
		<xsl:variable name="firstvar" select="$root/ddi:dataDscr/ddi:var[@ID=$vars[1]]"/>
		<xsl:for-each select="$vars">
			<xsl:variable name="position" select='position()'/>

			<!-- Output actual grid variable -->
			<xsl:apply-templates 
								 select="$root/ddi:dataDscr/ddi:var[@ID=current()/text()]"
								 mode="group">
				<xsl:with-param name="position" select="$position"/>
				<xsl:with-param name="stackedVarGrps" select="$stackedVarGrps"/>
			</xsl:apply-templates>
		</xsl:for-each>
	</xsl:template>

</xsl:stylesheet>
