<?xml version="1.0" encoding="UTF-8" ?>
<xsl:stylesheet version="1.0" 
				xmlns:fo="http://www.w3.org/1999/XSL/Format"
				xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
				xmlns:ddi="http://www.icpsr.umich.edu/DDI"
				xmlns:xhtml="http://www.w3.org/1999/xhtml" 
				xmlns:culture="http://nassess.byu.edu/culture"
				xmlns:ExsltStrings="http://fhss.byu.edu/exslt/strings"
				exclude-result-prefixes="ExsltStrings xsl ddi culture">

	<xsl:param name="GroupSelectOneOptionsOnLeft"/>
	<xsl:param name="alternatingRowColor" select="'#eeffee'"/>

	<xsl:attribute-set name="ResponseBox">
		<xsl:attribute name="text-align">center</xsl:attribute>
	</xsl:attribute-set>
	<xsl:attribute-set name="RadioList">
		<xsl:attribute name="start-indent">0.1in</xsl:attribute>
		<xsl:attribute name="provisional-distance-between-starts">0.25in</xsl:attribute>
		<xsl:attribute name="keep-together.within-column">always</xsl:attribute>
		<xsl:attribute name="keep-with-previous.within-column">always</xsl:attribute>
	</xsl:attribute-set>

	<xsl:template match="ddi:var[@intrvl='discrete'][ddi:varFormat/@type='numeric'][ddi:catgry]">
		<fo:block>
			<xsl:call-template name="preQTxt">
				<xsl:with-param name="var" select="."/>
			</xsl:call-template>
			<xsl:call-template name="QTxt">
				<xsl:with-param name="var" select="."/>
			</xsl:call-template>

			<xsl:apply-templates select="." mode="radio"/>

			<!-- If this variable has an Other response label, with an associated
			text field, render that text field here. -->
			<xsl:variable name="otherVar" select="../ddi:var[@ID=current()/ddi:codInstr][ddi:varFormat/@category='other']"/>
			<xsl:if test="$otherVar">
				<xsl:apply-templates select="$otherVar"/>
			</xsl:if>

			<xsl:call-template name="postQTxt">
				<xsl:with-param name="var" select="."/>
			</xsl:call-template>
		</fo:block>
	</xsl:template>

	<!-- Radio buttons -->
	<xsl:template mode="radio" match="ddi:var[@intrvl='discrete'][ddi:varFormat/@type='numeric'][ddi:catgry]">
		<xsl:variable name="var" select="."/>

		<!-- Render the options -->
		<fo:list-block xsl:use-attribute-sets="RadioList">
			<xsl:for-each select="ddi:catgry">
				<fo:list-item>
					<fo:list-item-label end-indent="label-end()">
						<fo:block>
							<xsl:value-of select="normalize-space(ddi:catValu)"/>
						</fo:block>
					</fo:list-item-label>
					<fo:list-item-body start-indent="body-start()">
						<fo:block>
							<xsl:apply-templates select="ddi:labl"/>
						</fo:block>
					</fo:list-item-body>
				</fo:list-item>
			</xsl:for-each>

		</fo:list-block>
	</xsl:template>

	<!-- GRID -->
	<xsl:template mode="group" match="ddi:var[@intrvl='discrete'][ddi:varFormat/@type='numeric'][ddi:catgry]">
		<xsl:param name="position"/>
		<xsl:param name="stackedVarGrps"/>
		<xsl:variable name="var" select="."/>

		<fo:table-row padding-before="0.5mm" padding-after="0.5mm">
			<xsl:if test="$position mod 2 = 1">
				<xsl:attribute name="background-color">
					<xsl:value-of select="$alternatingRowColor"/>
				</xsl:attribute>
			</xsl:if>
			<xsl:choose>
				<xsl:when test="$GroupSelectOneOptionsOnLeft">
					<xsl:apply-templates select="." mode="groupOptions">
						<xsl:with-param name="stackedVarGrps" select="$stackedVarGrps"/>
						<xsl:with-param name="position" select="$position"/>
					</xsl:apply-templates>
					<xsl:apply-templates select="." mode="groupQTxt"/>
				</xsl:when>
				<xsl:otherwise>
					<xsl:apply-templates select="." mode="groupQTxt"/>
					<xsl:apply-templates select="." mode="groupOptions">
						<xsl:with-param name="stackedVarGrps" select="$stackedVarGrps"/>
						<xsl:with-param name="position" select="$position"/>
					</xsl:apply-templates>
				</xsl:otherwise>
			</xsl:choose>
		</fo:table-row>
	</xsl:template>

	<xsl:template mode="groupOptions" match="ddi:var[@intrvl='discrete'][ddi:varFormat/@type='numeric'][ddi:catgry]">
		<xsl:param name="position"/>
		<xsl:param name="stackedVarGrps"/>
		<xsl:variable name="var" select="."/>

		<xsl:for-each select="ddi:catgry/ddi:catValu">
			<fo:table-cell>
				<fo:block xsl:use-attribute-sets="ResponseBox">
					<xsl:value-of select="normalize-space(.)"/>
				</fo:block>
			</fo:table-cell>
		</xsl:for-each>
		<xsl:if test="$stackedVarGrps">
			<xsl:for-each select="$stackedVarGrps">
				<xsl:variable name="guestVarID" select="ExsltStrings:tokenize(@var)[position() = $position]"/>
				<xsl:variable name="guestVar" select="$root/ddi:dataDscr/ddi:var[@ID=$guestVarID]"/>
				<xsl:for-each select="$guestVar/ddi:catgry/ddi:catValu">
					<fo:table-cell>
						<fo:block xsl:use-attribute-sets="ResponseBox">
							<xsl:value-of select="normalize-space(.)"/>
						</fo:block>
					</fo:table-cell>
				</xsl:for-each>
			</xsl:for-each>
		</xsl:if>
	</xsl:template>
	<xsl:template mode="groupQTxt" match="ddi:var[@intrvl='discrete'][ddi:varFormat/@type='numeric'][ddi:catgry]">
		<fo:table-cell padding-start="1mm" padding-end="2mm">
			<xsl:call-template name="QTxt">
				<xsl:with-param name="var" select="."/>
			</xsl:call-template>
			<!-- If there is an associated "other" box, draw it as well. -->
			<xsl:variable name="otherVar" select="../ddi:var[@ID=current()/ddi:codInstr][ddi:varFormat/@category='other']"/>
			<xsl:if test="$otherVar">
				<xsl:apply-templates select="$otherVar"/>
			</xsl:if>
		</fo:table-cell>
	</xsl:template>

</xsl:stylesheet>