using System;

namespace NAssess.Core.Engines.Reporting
{
	/// <summary>
	/// Summary description for XsltStdExtensions.
	/// </summary>
	public class XsltStdExtensions
	{
		public XsltStdExtensions()
		{
		}

		/// <summary>
		/// Generates a URL for a link to another page of a report.
		/// </summary>
		/// <param name="urlTemplate">
		/// The template URL given by the hosting web site used to 
		/// formulate the final URL.  
		/// This will be in a format similar to: 
		/// http://host/path/report.aspx?assessment={0}&amp;page={1}
		/// Where {0} is the placeholder for assessmentName, 
		/// and {1} is the placeholder for the pageNumber.
		/// </param>
		/// <param name="assessmentName">
		/// The name of the assessment with the report to jump to.
		/// </param>
		/// <param name="pageNumber">
		/// The page number to the target report to jump directly to.
		/// </param>
		/// <param name="namedAnchor">
		/// The point within the report page to have the browser scroll to.
		/// </param>
		/// <returns>
		/// The formulated URL.
		/// </returns>
		/// <remarks>
		/// This link will be good for use whether the target report page be
		/// just another page of the original report or a page on a different
		/// assessment.
		/// </remarks>
		public static string GetLinkToReport(string urlTemplate, string assessmentName, int pageNumber, string namedAnchor)
		{
			return string.Format(urlTemplate + "#{2}", assessmentName, pageNumber, namedAnchor);
		}
	}
}
