<?xml version="1.0" encoding="UTF-8" ?>
<xsl:stylesheet version="1.0" 
				xmlns:fo="http://www.w3.org/1999/XSL/Format"
				xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
				xmlns:nassess="http://nassess.byu.edu/report"
				xmlns:xhtml="http://www.w3.org/1999/xhtml" 
				xmlns:ExsltStrings="http://fhss.byu.edu/exslt/strings"
				exclude-result-prefixes="ExsltStrings xsl nassess">
				
<xsl:import href="project://NAssess.Core/Engines/Reporting/xslt/imports.xslt" />
<xsl:import href="project://NAssess.Core/Engines/Reporting/xslt.fo/global.xslt"/>

<!-- header styles -->
<xsl:attribute-set name="h1">
	<xsl:attribute name="text-align">center</xsl:attribute>
	<xsl:attribute name="font-family">Arial Black</xsl:attribute>
	<xsl:attribute name="font-size">24pt</xsl:attribute>
	<xsl:attribute name="border-bottom">2pt solid black</xsl:attribute>
	<xsl:attribute name="keep-with-next.within-page">always</xsl:attribute>
	<xsl:attribute name="break-before">page</xsl:attribute>
</xsl:attribute-set>
<xsl:attribute-set name="h2">
	<xsl:attribute name="font-family">Tahoma, MS Sans Serif, Trebuchet MS, Verdana, Tahoma, Arial, Helvetica, Sans-Serif</xsl:attribute>
	<xsl:attribute name="font-size">18pt</xsl:attribute>
	<xsl:attribute name="font-weight">bold</xsl:attribute>
	<xsl:attribute name="text-align">left</xsl:attribute>
<!--	<xsl:attribute name="border-bottom">1pt solid black</xsl:attribute>
	<xsl:attribute name="background-color">silver</xsl:attribute>-->
	<xsl:attribute name="space-before.optimum">14pt</xsl:attribute>
	<xsl:attribute name="space-before.minimum">0pt</xsl:attribute>
	<xsl:attribute name="space-after.optimum">8pt</xsl:attribute>
	<xsl:attribute name="keep-with-next.within-page">always</xsl:attribute>
</xsl:attribute-set>
<xsl:attribute-set name="h3">
	<xsl:attribute name="font-family">Tahoma, MS Sans Serif, Trebuchet MS, Verdana, Tahoma, Arial, Helvetica, Sans-Serif</xsl:attribute>
	<xsl:attribute name="font-size">16pt</xsl:attribute>
	<xsl:attribute name="font-weight">bold</xsl:attribute>
	<xsl:attribute name="text-align">start</xsl:attribute>
	<xsl:attribute name="space-before.optimum">8pt</xsl:attribute>
	<xsl:attribute name="space-before.minimum">4pt</xsl:attribute>
	<xsl:attribute name="space-after">4pt</xsl:attribute>
	<xsl:attribute name="padding-before">1pt</xsl:attribute>
	<xsl:attribute name="padding-after">1pt</xsl:attribute>
	<xsl:attribute name="padding-start">4pt</xsl:attribute>
	<xsl:attribute name="padding-end">0pt</xsl:attribute>
	<xsl:attribute name="keep-with-next.within-page">always</xsl:attribute>
</xsl:attribute-set>
<xsl:attribute-set name="h4">
	<xsl:attribute name="font-size">14pt</xsl:attribute>
	<xsl:attribute name="font-weight">bold</xsl:attribute>
	<xsl:attribute name="text-indent">0pt</xsl:attribute>
	<xsl:attribute name="space-before.optimum">12pt</xsl:attribute>
	<xsl:attribute name="keep-with-next.within-page">always</xsl:attribute>
</xsl:attribute-set>
<xsl:attribute-set name="h5">
	<xsl:attribute name="text-align">center</xsl:attribute>
	<xsl:attribute name="font-size">13pt</xsl:attribute>
	<xsl:attribute name="font-weight">bold</xsl:attribute>
	<xsl:attribute name="text-indent">0pt</xsl:attribute>
	<xsl:attribute name="space-before.optimum">12pt</xsl:attribute>
	<xsl:attribute name="keep-with-next.within-page">always</xsl:attribute>
</xsl:attribute-set>
<xsl:attribute-set name="h6">
	<xsl:attribute name="text-align">left</xsl:attribute>
	<xsl:attribute name="font-weight">bold</xsl:attribute>
	<xsl:attribute name="space-before.optimum">12pt</xsl:attribute>
	<xsl:attribute name="keep-with-next.within-page">always</xsl:attribute>
</xsl:attribute-set>

<!-- list styles -->
<xsl:attribute-set name="list-geometry">
	<xsl:attribute name="provisional-distance-between-starts">16pt</xsl:attribute>
	<xsl:attribute name="provisional-label-separation">4pt</xsl:attribute>
</xsl:attribute-set>
<xsl:attribute-set name="list-item-geometry">
	<xsl:attribute name="space-before.minimum">0pt</xsl:attribute>
	<xsl:attribute name="space-before.optimum">9pt</xsl:attribute>
	<xsl:attribute name="space-after.optimum">9pt</xsl:attribute>
</xsl:attribute-set>

<!-- paragraph styles -->
<xsl:attribute-set name="p">
	<xsl:attribute name="space-after.minimum">4pt</xsl:attribute>
	<xsl:attribute name="space-after.optimum">12pt</xsl:attribute>
	<xsl:attribute name="space-after.maximum">18pt</xsl:attribute>
</xsl:attribute-set>
<xsl:attribute-set name="div">
	<xsl:attribute name="space-after.minimum">4pt</xsl:attribute>
	<xsl:attribute name="space-after.optimum">12pt</xsl:attribute>
	<xsl:attribute name="space-after.maximum">18pt</xsl:attribute>
</xsl:attribute-set>
<xsl:attribute-set name="blockquote">
	<xsl:attribute name="margin-left">0.4in</xsl:attribute>
	<xsl:attribute name="space-before.minimum">4pt</xsl:attribute>
</xsl:attribute-set>

	<!-- This template knocks out any HTML we are not prepared to convert to FO -->
	<xsl:template match="xhtml:*">
		<fo:block>&lt;<xsl:value-of select="name()"/>&gt; not handled.</fo:block>
	</xsl:template>

	<!-- Header tags -->
	<xsl:template match="xhtml:h1">
		<fo:block xsl:use-attribute-sets="h1">
			<xsl:apply-templates select="*|text()"/>
		</fo:block>
	</xsl:template>
	<xsl:template match="xhtml:h1/xhtml:em">
		<fo:block font-style="italic" font-size="20pt">
			<xsl:apply-templates select="*|text()"/>
		</fo:block>
	</xsl:template>
	<xsl:template match="xhtml:h2">
		<fo:block xsl:use-attribute-sets="h2">
			<xsl:apply-templates select="*|text()"/>
		</fo:block>
	</xsl:template>
	<xsl:template match="xhtml:h2/xhtml:em">
		<fo:block font-style="italic" font-size="14pt">
			<xsl:apply-templates select="*|text()"/>
		</fo:block>
	</xsl:template>
	<xsl:template match="xhtml:h3">
		<fo:block xsl:use-attribute-sets="h3">
			<xsl:apply-templates select="*|text()"/>
		</fo:block>
	</xsl:template>
	<xsl:template match="xhtml:h4">
		<fo:block xsl:use-attribute-sets="h4">
			<xsl:apply-templates select="*|text()"/>
		</fo:block>
	</xsl:template>
	<xsl:template match="xhtml:h5">
		<fo:block xsl:use-attribute-sets="h5">
			<xsl:apply-templates select="*|text()"/>
		</fo:block>
	</xsl:template>
	<xsl:template match="xhtml:h6">
		<fo:inline xsl:use-attribute-sets="h6">
			<xsl:apply-templates select="*|text()"/>
		</fo:inline>
	</xsl:template>
	
	<!-- paragraph tags -->
	<xsl:template match="xhtml:p">
		<fo:block xsl:use-attribute-sets="p">
			<xsl:if test="@align"><xsl:attribute name="text-align"><xsl:value-of select="@align"/></xsl:attribute></xsl:if>
			<xsl:apply-templates select="*|text()"/>
		</fo:block>
	</xsl:template>
	<xsl:template match="xhtml:div">
		<fo:block xsl:use-attribute-sets="div">
			<xsl:if test="@align"><xsl:attribute name="text-align"><xsl:value-of select="@align"/></xsl:attribute></xsl:if>
			<xsl:apply-templates select="*|text()"/>
		</fo:block>
	</xsl:template>
	<xsl:template match="xhtml:br">
		<fo:block/>
	</xsl:template>
	<xsl:template match="xhtml:blockquote">
		<fo:block xsl:use-attribute-sets="blockquote">
			<xsl:apply-templates select="*|text()"/>
		</fo:block>
	</xsl:template>

	<!-- list tags -->
	<xsl:template match="xhtml:ul | xhtml:ol">
		<!-- TODO: output numbered lists for OL tags rather than a bulleted list. -->
		<fo:list-block xsl:use-attribute-sets="list-geometry">
			<xsl:apply-templates select="*|text()"/>
		</fo:list-block>
	</xsl:template>
	<xsl:template match="xhtml:li">
		<xsl:param name="context"/>		
		<fo:list-item xsl:use-attribute-sets="list-item-geometry">
			<fo:list-item-label start-indent="0.2in" end-indent="label-end()">
				<fo:block>
					<fo:character character="&#x25A0;" font-family="Book Antiqua" />
				</fo:block>
			</fo:list-item-label>
			<fo:list-item-body start-indent="body-start()">
				<fo:block>
					<xsl:apply-templates select="*|text()">
						<xsl:with-param name="context" select="$context"/>
					</xsl:apply-templates>
				</fo:block>
			</fo:list-item-body>
		</fo:list-item>			
	</xsl:template>
	
	<!-- in-line formatting tags -->
	<xsl:template match="xhtml:b"><fo:inline font-weight="bold"><xsl:apply-templates /></fo:inline></xsl:template>
	<xsl:template match="xhtml:em|xhtml:i"><fo:inline font-style="italic"><xsl:apply-templates /></fo:inline></xsl:template>
	
	<!-- image tags -->
	<xsl:template match="xhtml:img">
		<fo:block>[Image here]</fo:block>
	</xsl:template>
	
	<xsl:template match="img">
		<fo:block>[no-namespace image here]</fo:block>
	</xsl:template>
	
	<!-- table tags -->
	<xsl:template match="xhtml:table[@align]">
		<fo:block>
			<xsl:if test="@align"><xsl:attribute name="text-align"><xsl:value-of select='@align'/></xsl:attribute></xsl:if>
			<fo:inline-container>
				<fo:table>
					<xsl:if test="@border">
						<xsl:attribute name="border-width"><xsl:value-of select="@border"/>px</xsl:attribute>
						<xsl:attribute name="border-color">black</xsl:attribute>
						<xsl:attribute name="border-style">solid</xsl:attribute>
						<xsl:attribute name="margin-top">12pt</xsl:attribute>
					</xsl:if>
					<xsl:apply-templates select="@width"/>
					<fo:table-body>
						<xsl:apply-templates/>
					</fo:table-body>
				</fo:table>
			</fo:inline-container>
		</fo:block>
	</xsl:template>
	<xsl:template match="xhtml:table[not(@align)]">
		<fo:table>
			<xsl:if test="@border">
				<xsl:attribute name="border-width"><xsl:value-of select="@border"/>px</xsl:attribute>
				<xsl:attribute name="border-color">black</xsl:attribute>
				<xsl:attribute name="border-style">solid</xsl:attribute>
				<xsl:attribute name="margin-top">12pt</xsl:attribute>
			</xsl:if>
			<xsl:apply-templates select="@width"/>
			<fo:table-body>
				<xsl:apply-templates/>
			</fo:table-body>
		</fo:table>
	</xsl:template>
	<xsl:template match="xhtml:tr">
		<fo:table-row>
			<xsl:apply-templates/>
		</fo:table-row>
	</xsl:template>
	<xsl:template match="xhtml:td">
		<fo:table-cell>
			<xsl:if test="@colspan">
				<xsl:attribute name="number-columns-spanned"><xsl:value-of select="@colspan"/></xsl:attribute>
			</xsl:if>
			<xsl:if test="@align">
				<xsl:attribute name="text-align"><xsl:value-of select="@align"/></xsl:attribute>
			</xsl:if>
			<xsl:if test="@width">
				<xsl:attribute name="width"><xsl:value-of select="@width"/><xsl:if test="not(substring(@width, string-length(@width))='%')">px</xsl:if></xsl:attribute>
			</xsl:if>
			<xsl:if test="@valign='top' or @valign='middle' or @valign='bottom'">
				<xsl:attribute name="display-align">
					<xsl:choose>
						<xsl:when test="@valign='top'">before</xsl:when>
						<xsl:when test="@valign='middle'">center</xsl:when>
						<xsl:when test="@valign='bottom'">after</xsl:when>
					</xsl:choose>
				</xsl:attribute>
			</xsl:if>
			<fo:block>
				<xsl:apply-templates/>
			</fo:block>
		</fo:table-cell>
	</xsl:template>
	
	<!-- anchor tags -->
	<xsl:template match="xhtml:a[@href]">
		<!-- just render the contents of the tag without the link -->
		<xsl:apply-templates />

		<!-- See if the contents of the tag match exactly what the link is pointing at -->
		<xsl:if test="* or text() != @href">
			<!-- output the contents, followed by the link in parentheses -->
			<xsl:text> (</xsl:text>
			<xsl:value-of select="@href"/>
			<xsl:text>)</xsl:text>
		</xsl:if>
	</xsl:template>
	
</xsl:stylesheet>
