<?xml version="1.0" encoding="UTF-8" ?>
<xsl:stylesheet version="1.0" 
				xmlns:fo="http://www.w3.org/1999/XSL/Format"
				xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
				xmlns:nassess="http://nassess.byu.edu/report"
				xmlns:xhtml="http://www.w3.org/1999/xhtml" 
				xmlns:culture="http://nassess.byu.edu/culture"
				xmlns:ext="http://nassess.byu.edu/report/extensions"
				xmlns:ExsltStrings="http://fhss.byu.edu/exslt/strings"
				exclude-result-prefixes="ExsltStrings xsl nassess">

<xsl:import href="project://NAssess.Core/Engines/Reporting/xslt/imports.xslt" />
<xsl:import href="project://NAssess.Core/Engines/Reporting/xslt.fo/global.xslt" />
<xsl:import href="project://NAssess.Core/Engines/Reporting/xslt.fo/if.viewer.xslt"/>
<xsl:import href="project://NAssess.Core/Engines/Reporting/xslt.fo/scale.checklist.xslt"/>
<xsl:import href="project://NAssess.Core/Engines/Reporting/xslt.fo/scale.multibar.xslt"/>
<xsl:import href="project://NAssess.Core/Engines/Reporting/xslt.fo/scale.graph.xslt"/>
<xsl:import href="project://NAssess.Core/Engines/Reporting/xslt.fo/scale.gradient.xslt"/>
<xsl:import href="project://NAssess.Core/Engines/Reporting/xslt.fo/scale.table.xslt"/>
<xsl:import href="project://NAssess.Core/Engines/Reporting/xslt.fo/titlepage.xslt"/>
<xsl:import href="project://NAssess.Core/Engines/Reporting/xslt.fo/toc.xslt"/>
<xsl:import href="project://NAssess.Core/Engines/Reporting/xslt.fo/link.xslt"/>
<xsl:import href="project://NAssess.Core/Engines/Reporting/xslt.fo/img.xslt"/>
<xsl:import href="project://NAssess.Core/Engines/Reporting/xslt.fo/scaleGroup.xslt"/>

<!-- The following import(s) must fall at the END of the above list because of priority of imports requirements -->
<xsl:import href="project://NAssess.Core/Engines/Reporting/xslt.fo/html2fo.xslt" />

<xsl:strip-space elements="*"/>
<xsl:output method="xml" omit-xml-declaration='yes' indent='yes'/>

<xsl:param name="ReportTitle"/>
<xsl:param name="ReportSubTitle"/>
<xsl:param name="TodaysDate"/>

<xsl:attribute-set name="base">
	<xsl:attribute name="font-family">Georgia, Book Antiqua, Bookman Old Style, Times Roman, serif</xsl:attribute>
	<xsl:attribute name="font-size">12pt</xsl:attribute>
	<xsl:attribute name="text-align">justify</xsl:attribute>
	<xsl:attribute name="text-indent">0pt</xsl:attribute> <!-- this can indent the first line in a paragraph -->
</xsl:attribute-set>

	<xsl:template match="nassess:report">
		<fo:root>
			<fo:layout-master-set>
				
				<fo:simple-page-master master-name="titlePage" page-width="8.5in" page-height="11in">
					<fo:region-body
						margin-top="0.5in"
						margin-bottom="1in"
						margin-left="0.5in"
						margin-right="0.5in"/>
				</fo:simple-page-master>
				
				<fo:simple-page-master master-name="tocPage" page-width="8.5in" page-height="11in">
					<fo:region-body
						margin-top="0.5in"
						margin-bottom="1in"
						margin-left="0.5in"
						margin-right="0.5in"/>
					<fo:region-before region-name="tocHeader" extent="0.4in" />
					<fo:region-after region-name="tocFooter" extent="0.8in" />
				</fo:simple-page-master>
				
				<fo:simple-page-master master-name="content" page-width="8.5in" page-height="11in">
					<fo:region-body
						margin-top="0.5in"
						margin-bottom="1in"
						margin-left="0.5in"
						margin-right="0.5in"/>
					<fo:region-before region-name="contentHeader" extent="0.4in" />
					<fo:region-after region-name="contentFooter" extent="0.8in" />
				</fo:simple-page-master>
				
				<fo:page-sequence-master master-name="firstPages">
					<fo:single-page-master-reference master-reference="titlePage"/>
					<fo:single-page-master-reference master-reference="tocPage"/>
				</fo:page-sequence-master>					
				
				<fo:page-sequence-master master-name="contentPages">
					<fo:repeatable-page-master-reference master-reference="content"/>
				</fo:page-sequence-master>
			</fo:layout-master-set>
			
			<fo:page-sequence master-reference="firstPages"
						 initial-page-number="1" format="i">
				<fo:static-content flow-name="tocFooter">
					<fo:block text-align="center" space-after="8pt">
						<fo:page-number/>
					</fo:block>
				</fo:static-content>
				<fo:flow flow-name="xsl-region-body" xsl:use-attribute-sets="base">
					<xsl:call-template name="RenderTitlePage"/>
					<xsl:call-template name="RenderTOCPage"/>
				</fo:flow>
			</fo:page-sequence>
			
			<fo:page-sequence master-reference="contentPages"
						 initial-page-number="1" format="1">
				<fo:static-content flow-name="contentHeader">
					<fo:block display-align="after" text-align="center"><xsl:value-of select="$ReportTitle"/></fo:block>
				</fo:static-content>
				<fo:static-content flow-name="contentFooter">
					<fo:block text-align="center" space-after="8pt">
						<xsl:value-of select="culture:GetResourceStringXSLT('PageNumber')"/>
						<fo:page-number/>
					</fo:block>
				</fo:static-content>
				<fo:flow flow-name="xsl-region-body" xsl:use-attribute-sets="base">
					<xsl:apply-templates select="nassess:level" />
				</fo:flow>
			</fo:page-sequence>
			
		</fo:root>
	</xsl:template>
	
	<xsl:template match="nassess:level">
		<fo:block id="{@id}"> <!-- using a wrapper here disables clickable links in the PDF -->
			<xsl:apply-templates select="text()|*"/>
		</fo:block>
	</xsl:template>

</xsl:stylesheet>
