<?xml version="1.0" encoding="UTF-8" ?>
<xsl:stylesheet version="1.0" 
				xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
				xmlns:nassess="http://nassess.byu.edu/report"
				xmlns:fo="http://www.w3.org/1999/XSL/Format"
				xmlns:culture="http://nassess.byu.edu/culture"
				xmlns:ddi="http://www.icpsr.umich.edu/DDI"
				xmlns:xhtml="http://www.w3.org/1999/xhtml" 
				xmlns:ExsltStrings="http://fhss.byu.edu/exslt/strings"
				exclude-result-prefixes="ExsltStrings xsl nassess ddi">

<xsl:import href="project://NAssess.Core/Engines/Reporting/xslt/imports.xslt"/>
<xsl:import href="project://NAssess.Core/Engines/Reporting/xslt.fo/global.xslt"/>

<xsl:attribute-set name="checklist">
	 <xsl:attribute name="space-before">0.25in</xsl:attribute>
	 <xsl:attribute name="width">100%</xsl:attribute>
</xsl:attribute-set>
<xsl:attribute-set name="spacer">
</xsl:attribute-set>
<xsl:attribute-set name="CellBorder">
	<xsl:attribute name="border">1pt solid #dddddd</xsl:attribute>
</xsl:attribute-set>

<xsl:attribute-set name="Responses"> <!-- Jake's responses, Rhonda's responses -->
	<xsl:attribute name="number-columns-spanned">3</xsl:attribute>
	<xsl:attribute name="text-align">center</xsl:attribute>
</xsl:attribute-set>
<xsl:attribute-set name="AreaHeading">  <!-- title for: strength area / neutral area / challenge area -->
	<xsl:attribute name="text-align">center</xsl:attribute>
	<xsl:attribute name="background-color">#D7DFBF</xsl:attribute>
</xsl:attribute-set>
<xsl:attribute-set name="ItemLabel" use-attribute-sets="CellBorder">  <!-- Age, or any other item being listed -->
	<xsl:attribute name="text-align">left</xsl:attribute> <!-- overrides inherited justification -->
</xsl:attribute-set>
<xsl:attribute-set name="DataCell" use-attribute-sets="CellBorder">  <!-- any of the cells that a checkbox might appear in -->
	<xsl:attribute name="display-align">center</xsl:attribute>
	<xsl:attribute name="text-align">center</xsl:attribute>
</xsl:attribute-set>
<xsl:attribute-set name="StrengthCell" use-attribute-sets="DataCell">
	<xsl:attribute name="background-color">#ADEFAD</xsl:attribute>
</xsl:attribute-set>
<xsl:attribute-set name="NeutralCell" use-attribute-sets="DataCell">
	<xsl:attribute name="background-color">#FFFFFF</xsl:attribute>
</xsl:attribute-set>
<xsl:attribute-set name="ChallengeCell" use-attribute-sets="DataCell">
	<xsl:attribute name="background-color">#FF8C8C</xsl:attribute>
</xsl:attribute-set>


<xsl:param name="checkImageURL"/>

	<xsl:template match="nassess:scale[@type='checklist'][@refid]">
		<xsl:variable name="varGrpScaleID" select="@refid"/>
		<xsl:variable name="varGrpScale" select="$codebook/ddi:dataDscr/ddi:varGrp[@ID=$varGrpScaleID]"/>
		<fo:table xsl:use-attribute-sets="checklist">
			<xsl:attribute name="id"><xsl:value-of select="$varGrpScaleID"/></xsl:attribute>
			<fo:table-column column-number='1' column-width="35%"/>
			<fo:table-column column-number='2' column-width="10%"/>
			<fo:table-column column-number='3' column-width="10%"/>
			<fo:table-column column-number='4' column-width="10%"/>
			<fo:table-column column-number='5' column-width="5%"/>
			<fo:table-column column-number='6' column-width="10%"/>
			<fo:table-column column-number='7' column-width="10%"/>
			<fo:table-column column-number='8' column-width="10%"/>

			<fo:table-header>
				<!-- Top row: "Jake's Responses" -->
				<fo:table-row>
					<fo:table-cell number-rows-spanned='2'/>
					<xsl:for-each select="$participants">
						<xsl:if test="position() > 1">
							<fo:table-cell number-rows-spanned='2' xsl:use-attribute-sets="spacer" />
						</xsl:if>
						<fo:table-cell xsl:use-attribute-sets="Responses">
							<fo:block><xsl:value-of select="culture:GetResourceStringXSLT('ccResponses',@FriendlyName)"/></fo:block>
						</fo:table-cell>
					</xsl:for-each>
				</fo:table-row>
				<!-- Second heading row: "Strength Area    Neutral Area    Challenge Area" -->
				<fo:table-row>
					<xsl:for-each select="$participants">
						<fo:table-cell xsl:use-attribute-sets="AreaHeading">
							<fo:block><xsl:value-of select="culture:GetResourceStringXSLT('ccStrength')"/></fo:block>
						</fo:table-cell>
						<fo:table-cell xsl:use-attribute-sets="AreaHeading">
							<fo:block><xsl:value-of select="culture:GetResourceStringXSLT('ccNeutral')"/></fo:block>
						</fo:table-cell>
						<fo:table-cell xsl:use-attribute-sets="AreaHeading">
							<fo:block><xsl:value-of select="culture:GetResourceStringXSLT('ccChallenge')"/></fo:block>
						</fo:table-cell>
					</xsl:for-each>
				</fo:table-row>
			</fo:table-header>
			<fo:table-body>
				<xsl:variable name="itemIDs" select="ExsltStrings:tokenize($varGrpScale/@varGrp,' ')"/>
				<xsl:variable name="items" select="$codebook/ddi:dataDscr/ddi:varGrp[@ID=$itemIDs]"/>
				<xsl:for-each select="$items">
					<xsl:variable name="item" select="."/>
					<fo:table-row>
						<fo:table-cell xsl:use-attribute-sets="ItemLabel"><fo:block><xsl:apply-templates select="$item/ddi:labl"/></fo:block></fo:table-cell>
						<xsl:for-each select="$participants">
							<xsl:variable name="greenCutoff">
								<xsl:choose>
									<!-- Is there a gender-specific match? -->
									<xsl:when test="$item/ddi:concept/@vocab=concat(current()/@Gender,'G')">
										<xsl:value-of select="number($item/ddi:concept[@vocab=concat(current()/@Gender,'G')])"/>
									</xsl:when>
									<!-- Is there a gender-neutral match? -->
									<xsl:when test="$item/ddi:concept/@vocab='G'">
										<xsl:value-of select="number($item/ddi:concept[@vocab='G'])"/>
									</xsl:when>
								</xsl:choose>
							</xsl:variable>
							<xsl:variable name="redCutoff">
								<xsl:choose>
									<!-- Is there a gender-specific match? -->
									<xsl:when test="$item/ddi:concept/@vocab=concat(current()/@Gender,'R')">
										<xsl:value-of select="number($item/ddi:concept[@vocab=concat(current()/@Gender,'R')])"/>
									</xsl:when>
									<!-- Is there a gender-neutral match? -->
									<xsl:when test="$item/ddi:concept/@vocab='R'">
										<xsl:value-of select="number($item/ddi:concept[@vocab='R'])"/>
									</xsl:when>
								</xsl:choose>
							</xsl:variable>
							<xsl:variable name="StrengthIsAtLowEnd" select="$greenCutoff &lt; $redCutoff"/>

							<xsl:variable name="value">
								<xsl:call-template name="GetScaleValue">
									<xsl:with-param name="participant" select="current()"/>
									<xsl:with-param name="scaleName" select="$item/@ID"/>
								</xsl:call-template>
							</xsl:variable>

							<xsl:if test="position() > 1">
								<fo:table-cell xsl:use-attribute-sets='spacer' />
							</xsl:if>
							
							<fo:table-cell xsl:use-attribute-sets="StrengthCell">
								<xsl:if test="($StrengthIsAtLowEnd and $value &lt;= $greenCutoff) or (not($StrengthIsAtLowEnd) and $value &gt;= $greenCutoff)">
									<fo:block><!--<fo:external-graphic src="{$checkImageURL}"/>--><fo:character character="&#x221A;" /></fo:block>
								</xsl:if>
							</fo:table-cell>
							<fo:table-cell xsl:use-attribute-sets="NeutralCell">
								<xsl:if test="($value &lt; $greenCutoff and $value &gt; $redCutoff) or ($value &gt; $greenCutoff and $value &lt; $redCutoff)">
									<fo:block><fo:character character="&#x221A;" /></fo:block>
								</xsl:if>
							</fo:table-cell>
							<fo:table-cell xsl:use-attribute-sets="ChallengeCell">
								<xsl:if test="($StrengthIsAtLowEnd and $value &gt;= $redCutoff) or (not($StrengthIsAtLowEnd) and $value &lt;= $redCutoff)">
									<fo:block><fo:character character="&#x221A;" /></fo:block>
								</xsl:if>
							</fo:table-cell>
						</xsl:for-each>
					</fo:table-row>
				</xsl:for-each>
			</fo:table-body>
		</fo:table>
	</xsl:template>
	
</xsl:stylesheet>
