<?xml version="1.0" encoding="UTF-8" ?>
<xsl:stylesheet version="1.0" 
				xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
				xmlns:nassess="http://nassess.byu.edu/report"
				xmlns:fo="http://www.w3.org/1999/XSL/Format"
				xmlns:culture="http://nassess.byu.edu/culture"
				xmlns:ddi="http://www.icpsr.umich.edu/DDI"
				xmlns:xhtml="http://www.w3.org/1999/xhtml" 
				xmlns:ExsltStrings="http://fhss.byu.edu/exslt/strings"
				exclude-result-prefixes="ExsltStrings xsl nassess ddi">

<xsl:import href="project://NAssess.Core/Engines/Reporting/xslt/imports.xslt"/>
<xsl:import href="project://NAssess.Core/Engines/Reporting/xslt/scale.graph.xslt"/>
<xsl:import href="project://NAssess.Core/Engines/Reporting/xslt.fo/global.xslt"/>

<xsl:param name="graphURL"/>
<xsl:param name="graphLegendURL"/>
<xsl:param name="graphLabelsURL"/>

<xsl:attribute-set name="label">
</xsl:attribute-set>
<xsl:attribute-set name="bargraph">
</xsl:attribute-set>
<xsl:attribute-set name="legend">
</xsl:attribute-set>

<xsl:template match="nassess:scale[@type='bargraph'][@refid]">
	<fo:block>
		<xsl:apply-imports />
	</fo:block>
</xsl:template>

<xsl:template match="nassess:scale[@type='bargraph'][@refid]" mode='label'>
	<xsl:param name="GraphStyle"/>
	<xsl:param name="varGrpScale"/>
	<xsl:param name="FirstSelfVar"/>

	<xsl:choose>
		<xsl:when test="$graphLabelsURL">
			<fo:external-graphic xsl:use-attribute-sets="label">
				<xsl:if test="@height"><xsl:attribute name="height"><xsl:value-of select="@height"/><xsl:if test="not(substring(@height, string-length(@height))='%')">px</xsl:if></xsl:attribute></xsl:if>
				<xsl:attribute name="src">
					<xsl:text>url(</xsl:text>
					<xsl:call-template name="GetLabelURL">
						<xsl:with-param name="GraphStyle" select="$GraphStyle"/>
						<xsl:with-param name="varGrpScale" select="$varGrpScale"/>
						<xsl:with-param name="FirstSelfVar" select="$FirstSelfVar"/>
						<xsl:with-param name="scale" select="."/>
					</xsl:call-template>
					<xsl:text>)</xsl:text>
				</xsl:attribute>
			</fo:external-graphic>
		</xsl:when>
		<xsl:otherwise>
			[No path for graph labels image available.]
			<xsl:comment>Did you forget to provide a WebDirect path?</xsl:comment>
		</xsl:otherwise>
	</xsl:choose>
</xsl:template>
<xsl:template match="nassess:scale[@type='bargraph'][@refid]" mode='graph'>
	<xsl:param name="GraphStyle"/>
	<xsl:param name="varGrpScale"/>
	<xsl:param name="varGrpScaleID"/>
	<xsl:param name="FirstSelfVar"/>
	<xsl:param name="legendID"/>
	<xsl:variable name="scale" select="."/>

	<xsl:choose>
		<xsl:when test="$graphURL">
			<fo:external-graphic xsl:use-attribute-sets="bargraph">
				<xsl:if test="@height"><xsl:attribute name="height"><xsl:value-of select="@height"/><xsl:if test="not(substring(@height, string-length(@height))='%')">px</xsl:if></xsl:attribute></xsl:if>
				<xsl:if test="@width"><xsl:attribute name="width"><xsl:value-of select="@width"/><xsl:if test="not(substring(@width, string-length(@width))='%')">px</xsl:if></xsl:attribute></xsl:if>
				<xsl:attribute name="src">
					<xsl:text>url(</xsl:text>
					<xsl:call-template name="GetGraphURL">
						<xsl:with-param name="GraphStyle" select="$GraphStyle"/>
						<xsl:with-param name="varGrpScale" select="$varGrpScale"/>
						<xsl:with-param name="varGrpScaleID" select="$varGrpScaleID"/>
						<xsl:with-param name="FirstSelfVar" select="$FirstSelfVar"/>
						<xsl:with-param name="legendID" select="$legendID"/>
						<xsl:with-param name="scale" select="$scale"/>				
					</xsl:call-template>
					<xsl:text>)</xsl:text>
				</xsl:attribute>
			</fo:external-graphic>
		</xsl:when>
		<xsl:otherwise>
			[No path for bar graph image available.]
			<xsl:comment>Did you forget to provide a WebDirect path?</xsl:comment>
		</xsl:otherwise>
	</xsl:choose>
</xsl:template>

<xsl:template match="nassess:scale" mode='legend'>
	<!-- skip rendering of legend (on a PDF) when popup is specified -->
	<xsl:if test="not(@legend='popup')">

		<xsl:choose>
			<xsl:when test="$graphLegendURL">
				<fo:external-graphic xsl:use-attribute-sets="legend">
					<xsl:attribute name="src">
						<xsl:text>url(</xsl:text>
						<xsl:call-template name="GetLegendURL"/>
						<xsl:text>)</xsl:text>
					</xsl:attribute>
				</fo:external-graphic>
			</xsl:when>
			<xsl:otherwise>
				[No path for graph legend available.]
				<xsl:comment>Did you forget to provide a WebDirect path?</xsl:comment>
			</xsl:otherwise>
		</xsl:choose>
		
	</xsl:if>
</xsl:template>

</xsl:stylesheet>
