<?xml version="1.0" encoding="UTF-8" ?>
<xsl:stylesheet version="1.0" 
				xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
				xmlns:nassess="http://nassess.byu.edu/report"
				xmlns:fo="http://www.w3.org/1999/XSL/Format"
				xmlns:ddi="http://www.icpsr.umich.edu/DDI"
				xmlns:xhtml="http://www.w3.org/1999/xhtml" 
				xmlns:ExsltStrings="http://fhss.byu.edu/exslt/strings"
				exclude-result-prefixes="ExsltStrings xsl nassess ddi">

<xsl:import href="project://NAssess.Core/Engines/Reporting/xslt/global.xslt"/>
<xsl:import href="project://NAssess.Core/Engines/Reporting/xslt.fo/global.xslt"/>

<xsl:attribute-set name="scale">
	<xsl:attribute name="width">100%</xsl:attribute>
	<xsl:attribute name="space-before">12pt</xsl:attribute>
	<xsl:attribute name="space-after">12pt</xsl:attribute>
	<xsl:attribute name="text-align">center</xsl:attribute>
	<xsl:attribute name="display-align">center</xsl:attribute>
</xsl:attribute-set>

<xsl:attribute-set name="TopRow">
	<xsl:attribute name="font-weight">bold</xsl:attribute>
	<xsl:attribute name="display-align">after</xsl:attribute>
	<xsl:attribute name="text-align">center</xsl:attribute>
</xsl:attribute-set>
<xsl:attribute-set name="ScaleLabel">
	<xsl:attribute name="width">70%</xsl:attribute>
	<xsl:attribute name="text-align">start</xsl:attribute>
</xsl:attribute-set>
<xsl:attribute-set name="Participant">
	<xsl:attribute name="width">15%</xsl:attribute>
</xsl:attribute-set>

<xsl:attribute-set name="DataTableBody">
	<xsl:attribute name="font-size">10pt</xsl:attribute>
	<xsl:attribute name="padding">1pt</xsl:attribute>
	<xsl:attribute name="display-align">before</xsl:attribute>
</xsl:attribute-set>

<xsl:attribute-set name="Row">
</xsl:attribute-set>
<xsl:attribute-set name="AlternateRow">
</xsl:attribute-set>

<xsl:attribute-set name="VariableLabel">
	<xsl:attribute name="text-align">start</xsl:attribute>
</xsl:attribute-set>

	<xsl:template match="nassess:scale[@type='table'][@refid]">
		<xsl:variable name="varGrpScaleID" select="@refid"/>
		<xsl:variable name="varGrpScale" select="$codebook/ddi:dataDscr/ddi:varGrp[@ID=$varGrpScaleID]"/>
		<xsl:variable name="codebook" select="$varGrpScale/ancestor::ddi:codeBook"/>
		<xsl:if test="not($varGrpScale)">
			<fo:block font-weight="bold">[Scale <xsl:value-of select="@refid"/> cannot be found]</fo:block>
		</xsl:if>
		<fo:table xsl:use-attribute-sets="scale" id="{$varGrpScaleID}">
			<fo:table-header xsl:use-attribute-sets="TopRow">
				<fo:table-row>
					<fo:table-cell xsl:use-attribute-sets="ScaleLabel">
						<fo:block>
							<xsl:choose>
								<xsl:when test="string-length(normalize-space(text())) &gt; 0">
									<xsl:value-of select="text()"/>
								</xsl:when>
								<xsl:otherwise>
									<xsl:value-of select="normalize-space($varGrpScale/ddi:labl)"/>
								</xsl:otherwise>
							</xsl:choose>
						</fo:block>
					</fo:table-cell>
					<xsl:for-each select="$participants">
						<fo:table-cell xsl:use-attribute-sets="Participant"><fo:block>
							<xsl:value-of select="@FriendlyName"/>
						</fo:block></fo:table-cell>
					</xsl:for-each>
				</fo:table-row>
			</fo:table-header>
			<fo:table-body xsl:use-attribute-sets="DataTableBody">
				<xsl:variable name="vars" select="ExsltStrings:tokenize($varGrpScale/@var,' ')"/>
				<xsl:for-each select="$vars">
					<xsl:variable name="var" select="$codebook/ddi:dataDscr/ddi:var[@ID=current()/text()]"/>
					<fo:table-row>
						<xsl:if test="position() mod 2 = 1"><xsl:attribute name="background-color">#D7DFBF<!--#87cefa--></xsl:attribute></xsl:if>
						<fo:table-cell xsl:use-attribute-sets="VariableLabel"><fo:block>
							<xsl:value-of select="$var/ddi:labl"/>
						</fo:block></fo:table-cell>
						<xsl:for-each select="$participants">
							<fo:table-cell>
								<fo:block>
									<xsl:call-template name="GetValue">
										<xsl:with-param name="varName" select="$var/@name"/>
										<xsl:with-param name="participant" select="."/>
									</xsl:call-template>
								</fo:block>
							</fo:table-cell>
						</xsl:for-each>
					</fo:table-row>
				</xsl:for-each>
			</fo:table-body>
		</fo:table>
	</xsl:template>
	
</xsl:stylesheet>
