<?xml version="1.0" encoding="UTF-8" ?>
<xsl:stylesheet version="1.0" 
				xmlns:fo="http://www.w3.org/1999/XSL/Format"
				xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
				xmlns:nassess="http://nassess.byu.edu/report"
				xmlns:xhtml="http://www.w3.org/1999/xhtml" 
				xmlns:culture="http://nassess.byu.edu/culture"
				xmlns:ext="http://nassess.byu.edu/report/extensions"
				xmlns:ExsltStrings="http://fhss.byu.edu/exslt/strings"
				exclude-result-prefixes="ExsltStrings xsl nassess">

<xsl:param name="ReportTitle"/>
<xsl:param name="ReportSubTitle"/>
<xsl:param name="TodaysDate"/>
<xsl:param name="SealUrl"/>
<xsl:param name="imagesWithTextURL" />

<xsl:attribute-set name="ReportTitleStyle">
	<xsl:attribute name="text-align">center</xsl:attribute>
	<xsl:attribute name="display-align">center</xsl:attribute>
	<xsl:attribute name="padding-before">4in</xsl:attribute>
	<xsl:attribute name="font-family">Arial Black</xsl:attribute>
	<xsl:attribute name="font-size">24pt</xsl:attribute>
	<xsl:attribute name="keep-with-next.within-page">always</xsl:attribute>
	<xsl:attribute name="break-before">page</xsl:attribute>
</xsl:attribute-set>

<xsl:attribute-set name="SealStyle">
	<xsl:attribute name="space-before">2in</xsl:attribute>
	<xsl:attribute name="text-align">center</xsl:attribute>
</xsl:attribute-set>

	<xsl:template name="RenderTitlePage">
		<!-- Render title page -->
		<fo:block xsl:use-attribute-sets="ReportTitleStyle">
			<!-- print the title of the report -->
			<xsl:value-of select="$ReportTitle"/>

			<!-- list the participants whose data is included in this report -->
			<fo:block font-size="18pt" font-family="Times New Roman, Serif">
				<xsl:choose>
					<xsl:when test="count($participants) = 2">
						<xsl:value-of select="$participants[1]/@FriendlyName"/>
						<xsl:text> </xsl:text>
						<xsl:value-of select="culture:GetResourceStringXSLT('ParticipantListingAnd')"/>
						<xsl:text> </xsl:text>
						<xsl:value-of select="$participants[2]/@FriendlyName"/>
					</xsl:when>
					<xsl:otherwise>
						<xsl:for-each select="$participants">
							<xsl:value-of select="@FriendlyName"/>
							<xsl:if test="position() != last()"><xsl:text>, </xsl:text></xsl:if>
						</xsl:for-each>
					</xsl:otherwise>
				</xsl:choose>
			</fo:block>

			<!-- print date -->
			<fo:block font-size="14pt" font-family="Times New Roman, Serif">
				<xsl:value-of select="$TodaysDate"/>
			</fo:block>

		</fo:block>
		
		<fo:block xsl:use-attribute-sets="SealStyle">
			<xsl:if test="$SealUrl">
				<fo:external-graphic src="url({$SealUrl})"/>
			</xsl:if>
		</fo:block>

<!--
	 <fo:block xsl:use-attribute-sets="sectiontitle">
			<xsl:value-of select="title"/>
			
			<fo:block space-before="0.5in" font-size="14pt" font-family="Times New Roman, Serif">
				<xsl:text>The RELATE Institute</xsl:text>
			</fo:block>
			<fo:block font-size="14pt" font-family="Times New Roman, Serif">
				<xsl:text>www.relate-institute.org</xsl:text>
			</fo:block>
		</fo:block>
-->
	</xsl:template>

</xsl:stylesheet>
