<?xml version="1.0" encoding="UTF-8" ?>
<xsl:stylesheet version="1.0" 
				xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
				xmlns:nassess="http://nassess.byu.edu/report"
				xmlns:ext="http://nassess.byu.edu/rendering/report/standardextensions"
				xmlns="http://www.w3.org/1999/xhtml" 
				xmlns:ExsltStrings="http://fhss.byu.edu/exslt/strings"
				exclude-result-prefixes="ExsltStrings xsl nassess">
				
<xsl:import href="project://NAssess.Core/Engines/Reporting/xslt/imports.xslt" />
<xsl:import href="project://NAssess.Core/Engines/Reporting/xslt.html/global.xslt"/>

<xsl:param name="linkWithinReportURL"/>
<xsl:param name="linkExternalReportURLs"/>

	<!-- This template is for link targets -->
	<xsl:template match="nassess:link[@id]">
		<a name="{@id}">
			
			<!-- There may not be any content for this tag, but just in case... -->
			<xsl:apply-templates select="*|text()"/>
		
		</a>
	</xsl:template>
	
	<!-- This template is for link sources, whether for links within this report or to external reports -->
	<xsl:template match="nassess:link[@ref]">
		<xsl:call-template name="link">
			<xsl:with-param name="referrer" select="."/>
			<xsl:with-param name="ref" select="@ref"/>
			<xsl:with-param name="report" select="@report"/>
			<xsl:with-param name="content" select="text()|*"/>
		</xsl:call-template>
	</xsl:template>
		
	<xsl:template name="link">
		<xsl:param name="referrer"/>
		<xsl:param name="ref"/>
		<xsl:param name="report"/>
		<xsl:param name="content"/>
		
		<xsl:choose>
			<xsl:when test="$report and $linkExternalReportURLs"> <!-- for linking outside the current report -->
				
				<xsl:variable name="externalReport" select="$linkExternalReportURLs[@FriendlyName=$report]"/>
				<xsl:variable name="TargetPage" select="$externalReport/nassess:report/nassess:level[descendant::nassess:link[@id=$ref]]"/>
				<xsl:choose>
					<!-- only create link when we can find the target report and page number -->
					<xsl:when test="$externalReport and $TargetPage">
						<xsl:variable name="TargetPageNum" select="count($TargetPage/preceding-sibling::nassess:level)+1"/>
						
						<a href="{ext:GetLinkToReport($externalReport/@URL, $report, $TargetPageNum, $ref)}">
							<xsl:apply-templates select="$content"/>
						</a>
					</xsl:when>
					<!-- At very least, just don't render the link, but get the content there -->
					<xsl:otherwise>
						<xsl:apply-templates select="$content"/>
					</xsl:otherwise>
				</xsl:choose>
				
			</xsl:when>
			<xsl:when test="not($report)"> <!-- for linking within the current report -->
				
				<xsl:variable name="TargetPage" select="/nassess:report/nassess:level[descendant::nassess:link[@id=$ref]]"/>

				<xsl:choose>
					<!-- When the link target is a descendant of an ancestor of this link source (when we're cousins on the same page) -->
					<xsl:when test="$TargetPage/descendant::* = $referrer">
						<!-- This link is within the same page -->
						<a href="#{$ref}">
							<xsl:apply-templates select="$content"/>
						</a>
					</xsl:when>
					<!-- This link is on another page of this same report, and we have the link to use -->
					<xsl:when test="$TargetPage and $linkWithinReportURL">
						<xsl:variable name="TargetPageNum" select="count($TargetPage/preceding-sibling::nassess:level)+1"/>
						<a href="{ext:GetLinkToReport($linkWithinReportURL, $AssessmentName, $TargetPageNum, $ref)}">
							<xsl:apply-templates select="$content"/>
						</a>
					</xsl:when>
					<!-- At very least, just don't render the link, but get the content there -->
					<xsl:otherwise>
						<xsl:apply-templates select="$content"/>
					</xsl:otherwise>
				</xsl:choose>
			</xsl:when>
			<xsl:otherwise>
				<!-- At very least, just don't render the link, but get the content there -->
				<xsl:apply-templates select="$content"/>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>
	
</xsl:stylesheet>
