<?xml version="1.0" encoding="UTF-8" ?>
<xsl:stylesheet version="1.0" 
				xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
				xmlns:nassess="http://nassess.byu.edu/report"
				xmlns:ddi="http://www.icpsr.umich.edu/DDI"
				xmlns="http://www.w3.org/1999/xhtml" 
				xmlns:ExsltStrings="http://fhss.byu.edu/exslt/strings"
				xmlns:culture="http://nassess.byu.edu/culture"
				exclude-result-prefixes="ExsltStrings xsl nassess ddi">

<xsl:import href="project://NAssess.Core/Engines/Reporting/xslt/global.xslt"/>
<xsl:import href="project://NAssess.Core/Engines/Reporting/xslt.html/global.xslt"/>

<xsl:param name="checkImageURL"/>

	<xsl:template match="nassess:scale[@type='checklist'][@refid]">
		<xsl:variable name="varGrpScaleID" select="@refid"/>
		<xsl:variable name="varGrpScale" select="$codebook/ddi:dataDscr/ddi:varGrp[@ID=$varGrpScaleID]"/>
		<table class="checklist">
			<xsl:attribute name="id"><xsl:value-of select="$varGrpScaleID"/></xsl:attribute>
			<thead>
				<!-- Top row: "Jake's Responses" -->
				<tr>
					<th rowspan='2'/>
					<xsl:for-each select="$participants">
						<xsl:if test="position() > 1">
							<td rowspan='2' class="spacer" />
						</xsl:if>
						<th colspan='3' class="Responses">
							<xsl:value-of select="culture:GetResourceStringXSLT('ccResponses',@FriendlyName)"/>
						</th>
					</xsl:for-each>
				</tr>
				<!-- Second heading row: "Strength Area    Neutral Area    Challenge Area" -->
				<tr>
					<xsl:for-each select="$participants">
						<th class="area">
							<xsl:value-of select="culture:GetResourceStringXSLT('ccStrength')"/>
						</th>
						<th class="area">
							<xsl:value-of select="culture:GetResourceStringXSLT('ccNeutral')"/>
						</th>
						<th class="area">
							<xsl:value-of select="culture:GetResourceStringXSLT('ccChallenge')"/>
						</th>
					</xsl:for-each>
				</tr>
			</thead>
			<tbody>
				<xsl:variable name="itemIDs" select="ExsltStrings:tokenize($varGrpScale/@varGrp,' ')"/>
				<xsl:variable name="items" select="$codebook/ddi:dataDscr/ddi:varGrp[@ID=$itemIDs]"/>
				<xsl:for-each select="$items">
					<xsl:variable name="item" select="."/>
					<tr>
						<th><xsl:apply-templates select="$item/ddi:labl"/></th>
						<xsl:for-each select="$participants">
							<xsl:variable name="greenCutoff">
								<xsl:choose>
									<!-- Is there a gender-specific match? -->
									<xsl:when test="$item/ddi:concept/@vocab=concat(current()/@Gender,'G')">
										<xsl:value-of select="number($item/ddi:concept[@vocab=concat(current()/@Gender,'G')])"/>
									</xsl:when>
									<!-- Is there a gender-neutral match? -->
									<xsl:when test="$item/ddi:concept/@vocab='G'">
										<xsl:value-of select="number($item/ddi:concept[@vocab='G'])"/>
									</xsl:when>
								</xsl:choose>
							</xsl:variable>
							<xsl:variable name="redCutoff">
								<xsl:choose>
									<!-- Is there a gender-specific match? -->
									<xsl:when test="$item/ddi:concept/@vocab=concat(current()/@Gender,'R')">
										<xsl:value-of select="number($item/ddi:concept[@vocab=concat(current()/@Gender,'R')])"/>
									</xsl:when>
									<!-- Is there a gender-neutral match? -->
									<xsl:when test="$item/ddi:concept/@vocab='R'">
										<xsl:value-of select="number($item/ddi:concept[@vocab='R'])"/>
									</xsl:when>
								</xsl:choose>
							</xsl:variable>
							<xsl:variable name="StrengthIsAtLowEnd" select="$greenCutoff &lt; $redCutoff"/>

							<xsl:variable name="value">
								<xsl:call-template name="GetScaleValue">
									<xsl:with-param name="participant" select="current()"/>
									<xsl:with-param name="scaleName" select="$item/@ID"/>
								</xsl:call-template>
							</xsl:variable>

							<xsl:if test="position() > 1">
								<td class='spacer' />
							</xsl:if>
							
							<td class="green">
								<xsl:if test="($StrengthIsAtLowEnd and $value &lt;= $greenCutoff) or (not($StrengthIsAtLowEnd) and $value &gt;= $greenCutoff)">
									<img src="{$checkImageURL}"/>
								</xsl:if>
							</td>
							<td class="neutral">
								<xsl:if test="($value &lt; $greenCutoff and $value &gt; $redCutoff) or ($value &gt; $greenCutoff and $value &lt; $redCutoff)">
									<img src="{$checkImageURL}"/>
								</xsl:if>
							</td>
							<td class="red">
								<xsl:if test="($StrengthIsAtLowEnd and $value &gt;= $redCutoff) or (not($StrengthIsAtLowEnd) and $value &lt;= $redCutoff)">
									<img src="{$checkImageURL}"/>
								</xsl:if>
							</td>
						</xsl:for-each>
					</tr>
				</xsl:for-each>
			</tbody>
		</table>
	</xsl:template>
	
</xsl:stylesheet>
