<?xml version="1.0" encoding="UTF-8" ?>
<xsl:stylesheet version="1.0" 
				xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
				xmlns:nassess="http://nassess.byu.edu/report"
				xmlns:culture="http://nassess.byu.edu/culture"
				xmlns:msxsl="urn:schemas-microsoft-com:xslt"
				xmlns:ddi="http://www.icpsr.umich.edu/DDI"
				xmlns="http://www.w3.org/1999/xhtml" 
				xmlns:ExsltStrings="http://fhss.byu.edu/exslt/strings"
				exclude-result-prefixes="ExsltStrings xsl nassess ddi">

<xsl:import href="project://NAssess.Core/Engines/Reporting/xslt/imports.xslt"/>
<xsl:import href="project://NAssess.Core/Engines/Reporting/xslt.html/global.xslt"/>
<xsl:import href="project://NAssess.Core/Engines/Reporting/xslt/scale.graph.xslt"/>

<xsl:param name="graphURL"/>
<xsl:param name="graphLegendURL"/>
<xsl:param name="graphLabelsURL"/>

<xsl:template match="nassess:scale[@type='bargraph'][@refid]">
	<div class="scale">
		
		<xsl:apply-imports />
		
		<xsl:if test="@calculation">
			<p class="calculation">
				<xsl:call-template name="link">
					<xsl:with-param name="ref" select="@calculation"/>
					<xsl:with-param name="report" select="@calculationReport"/>
					<xsl:with-param name="content" select="culture:GetResourceStringXSLT('calculation')"/>
					<xsl:with-param name="referrer" select="."/>
				</xsl:call-template>
			</p>
		</xsl:if>
	</div>
</xsl:template>


<xsl:template match="nassess:scale[@type='bargraph'][@refid]" mode='label'>
	<xsl:param name="GraphStyle"/>
	<xsl:param name="varGrpScale"/>
	<xsl:param name="FirstSelfVar"/>
	
	<xsl:choose>
		<xsl:when test="$graphLabelsURL">
			<img class="label">
				<xsl:if test="@height"><xsl:attribute name="height"><xsl:value-of select="@height"/></xsl:attribute></xsl:if>
				<xsl:attribute name="src">
					<xsl:call-template name="GetLabelURL">
						<xsl:with-param name="GraphStyle" select="$GraphStyle"/>
						<xsl:with-param name="varGrpScale" select="$varGrpScale"/>
						<xsl:with-param name="FirstSelfVar" select="$FirstSelfVar"/>
						<xsl:with-param name="scale" select="."/>
					</xsl:call-template>
				</xsl:attribute>
			</img>
		</xsl:when>
		<xsl:otherwise>
			[No path for graph labels image available.]
			<xsl:comment>Did you forget to provide a WebDirect path?</xsl:comment>
		</xsl:otherwise>
	</xsl:choose>
</xsl:template>
<xsl:template match="nassess:scale[@type='bargraph'][@refid]" mode='graph'>
	<xsl:param name="GraphStyle"/>
	<xsl:param name="varGrpScale"/>
	<xsl:param name="varGrpScaleID"/>
	<xsl:param name="FirstSelfVar"/>
	<xsl:param name="legendID"/>
	<xsl:variable name="scale" select="."/>
	
	<xsl:choose>
		<xsl:when test="$graphURL">
			<img class="bargraph">
				<xsl:if test="@legend='popup'">
					<xsl:attribute name="onmouseover">showLegend(<xsl:value-of select="$legendID"/>); </xsl:attribute>
					<xsl:attribute name="onmouseout">hideLegend(<xsl:value-of select="$legendID"/>);</xsl:attribute>
				</xsl:if>
				<xsl:if test="@width"><xsl:attribute name="width"><xsl:value-of select="@width"/></xsl:attribute></xsl:if>
				<xsl:if test="@height"><xsl:attribute name="height"><xsl:value-of select="@height"/></xsl:attribute></xsl:if>
				<xsl:attribute name="src">
					<xsl:call-template name="GetGraphURL">
						<xsl:with-param name="GraphStyle" select="$GraphStyle"/>
						<xsl:with-param name="varGrpScale" select="$varGrpScale"/>
						<xsl:with-param name="varGrpScaleID" select="$varGrpScaleID"/>
						<xsl:with-param name="FirstSelfVar" select="$FirstSelfVar"/>
						<xsl:with-param name="scale" select="$scale"/>				
					</xsl:call-template>
				</xsl:attribute>
			</img>
		</xsl:when>
		<xsl:otherwise>
			[No path for bar graph image available.]
			<xsl:comment>Did you forget to provide a WebDirect path?</xsl:comment>
		</xsl:otherwise>
	</xsl:choose>
</xsl:template>

<xsl:template match="nassess:scale" mode='legend'>
	<xsl:param name="legendID"/>
	
	<xsl:choose>
		<xsl:when test="$graphLegendURL">
			<img id='{$legendID}'>
				<xsl:attribute name="class">
					<xsl:choose>
						<xsl:when test="@legend='popup'">legendPopup</xsl:when>
						<xsl:otherwise>legend</xsl:otherwise>
					</xsl:choose>
				</xsl:attribute>
				<xsl:attribute name="src">
					<xsl:call-template name="GetLegendURL"/>
				</xsl:attribute>
			</img>
		</xsl:when>
		<xsl:otherwise>
			[No path for graph legend available.]
			<xsl:comment>Did you forget to provide a WebDirect path?</xsl:comment>
		</xsl:otherwise>
	</xsl:choose>
</xsl:template>

</xsl:stylesheet>
