<?xml version="1.0" encoding="UTF-8" ?>
<xsl:stylesheet version="1.0" 
				xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
				xmlns:nassess="http://nassess.byu.edu/report"
				xmlns:ddi="http://www.icpsr.umich.edu/DDI"
				xmlns="http://www.w3.org/1999/xhtml" 
				xmlns:ExsltStrings="http://fhss.byu.edu/exslt/strings"
				exclude-result-prefixes="ExsltStrings xsl nassess ddi">

<xsl:import href="project://NAssess.Core/Engines/Reporting/xslt/global.xslt"/>
<xsl:import href="project://NAssess.Core/Engines/Reporting/xslt.html/global.xslt"/>

	<xsl:template match="nassess:scale[@type='table'][@refid]">
		<xsl:variable name="varGrpScaleID" select="@refid"/>
		<xsl:variable name="varGrpScale" select="$codebook/ddi:dataDscr/ddi:varGrp[@ID=$varGrpScaleID]"/>
		<xsl:variable name="codebook" select="$varGrpScale/ancestor::ddi:codeBook"/>
		<xsl:if test="not($varGrpScale)">
			<b>[Scale <xsl:value-of select="@refid"/> cannot be found]</b>
		</xsl:if>
		<table class="scale" id="{$varGrpScaleID}">
			<thead>
				<tr>
					<th class="ScaleLabel">
						<xsl:choose>
							<xsl:when test="string-length(normalize-space(text())) &gt; 0">
								<xsl:value-of select="text()"/>
							</xsl:when>
							<xsl:otherwise>
								<xsl:value-of select="normalize-space($varGrpScale/ddi:labl)"/>
							</xsl:otherwise>
						</xsl:choose>
					</th>
					<xsl:for-each select="$participants">
						<th class="Participant"><xsl:value-of select="@FriendlyName"/></th>
					</xsl:for-each>
				</tr>
			</thead>
			<xsl:variable name="vars" select="ExsltStrings:tokenize($varGrpScale/@var,' ')"/>
			<xsl:for-each select="$vars">
				<xsl:variable name="var" select="$codebook/ddi:dataDscr/ddi:var[@ID=current()/text()]"/>
				<tr>
					<xsl:choose>
						<xsl:when test="position() mod 2 = 1">
							<xsl:attribute name="class">AlternateRow</xsl:attribute>
						</xsl:when>
						<xsl:otherwise>
							<xsl:attribute name="class">Row</xsl:attribute>
						</xsl:otherwise>
					</xsl:choose>
					<th><xsl:value-of select="$var/ddi:labl"/></th>
					<xsl:for-each select="$participants">
						<td>
							<xsl:call-template name="GetValue">
								<xsl:with-param name="varName" select="$var/@name"/>
								<xsl:with-param name="participant" select="."/>
							</xsl:call-template>
						</td>
					</xsl:for-each>
				</tr>
			</xsl:for-each>
		</table>
	</xsl:template>
	
</xsl:stylesheet>
