<?xml version="1.0" encoding="UTF-8" ?>
<xsl:stylesheet version="1.0" 
				xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
				xmlns:nassess="http://nassess.byu.edu/report"
				xmlns:ddi="http://www.icpsr.umich.edu/DDI"
				xmlns="http://www.w3.org/1999/xhtml" 
				xmlns:ExsltStrings="http://fhss.byu.edu/exslt/strings"
				exclude-result-prefixes="ExsltStrings xsl ddi nassess">

<xsl:import href="project://NAssess.Core/Engines/Reporting/xslt/global.xslt"/>

	<!-- Displaying property for first or specified participant -->
	<xsl:template match="nassess:property">
		<xsl:variable name="propertyName" select="@name" />
		
		<xsl:choose>
			<xsl:when test="@participant">
				<xsl:value-of select="$participants[position() = current()/@participant]/@*[name()=$propertyName]" />
			</xsl:when>
			<xsl:when test="not(@participant) and count($participants) = 1">
				<xsl:value-of select="$participants[1]/@*[name()=$propertyName]" />
			</xsl:when>
			<xsl:otherwise>
				[WARNING: value field's specific participant not specified when at least two participants exist.]
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>
	
	<!-- Display property within a <for each='participant'> loop -->
	<xsl:template match="nassess:property[ancestor::nassess:for[@each='participant']]">
		<xsl:param name="context"/>
		<xsl:value-of select="$context/@*[name()=current()/@name]" />
	</xsl:template>
	
	<xsl:template name="GetValue">
		<xsl:param name="participant" select="$participants[1]" />
		<xsl:param name="evaluation" />  <!-- reserved for later use -->
		<xsl:param name="codeBook" />  <!-- reserved for later use -->
		<xsl:param name="varName" />

		<!-- get absolute value of response -->
		<xsl:variable name="varValue" select="$participant/evaluation/responses/@*[name() = $varName]"/>
		<!-- look up whether this value has a label -->
		<xsl:variable name="varValueLabel" select="normalize-space($codebook/ddi:dataDscr/ddi:var[@name=$varName]/ddi:catgry[normalize-space(ddi:catValu)=$varValue]/ddi:labl)"/>
		
		<!-- If a label was available, display that.  Otherwise, display the actual value. -->
		<xsl:choose>
			<xsl:when test="$varValueLabel">
				<xsl:value-of select="$varValueLabel"/>
			</xsl:when>
			<xsl:otherwise>
				<xsl:value-of select="$varValue"/>
			</xsl:otherwise>
		</xsl:choose>		
	</xsl:template>
</xsl:stylesheet>