<?xml version="1.0" encoding="UTF-8" ?>
<xsl:stylesheet version="1.0" 
				xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
				xmlns:nassess="http://nassess.byu.edu/report"
				xmlns:culture="http://nassess.byu.edu/culture"
				xmlns:msxsl="urn:schemas-microsoft-com:xslt"
				xmlns:ddi="http://www.icpsr.umich.edu/DDI"
				xmlns="http://www.w3.org/1999/xhtml" 
				xmlns:ExsltStrings="http://fhss.byu.edu/exslt/strings"
				exclude-result-prefixes="ExsltStrings xsl nassess ddi">

<xsl:import href="project://NAssess.Core/Engines/Reporting/xslt/global.xslt"/>
<xsl:import href="project://NAssess.Core/Engines/Reporting/xslt/scale.value.xslt"/>
<xsl:import href="project://NAssess.Core/Engines/Reporting/xslt/scale.graph.xslt"/>

<xsl:param name="gGraphURL"/>
<xsl:param name="graphLegendURL"/>

	<xsl:template name="GetGradientGraphURL">
		<xsl:param name="varGrpScale"/>
		<xsl:param name="varGrpScaleID"/>
		<xsl:param name="FirstSelfVar"/>
		<xsl:param name="scale"/>

		<xsl:if test="$gGraphURL">
			<xsl:value-of select="$gGraphURL"/>
			<xsl:text>title=</xsl:text><xsl:value-of select="ExsltStrings:URLEncode(normalize-space($varGrpScale/ddi:labl))"/>
			<xsl:if test="$scale/@width">&amp;width=<xsl:value-of select="$scale/@width"/></xsl:if>
			<xsl:if test="$scale/@height">&amp;height=<xsl:value-of select="$scale/@height"/></xsl:if>
			<xsl:if test="$FirstSelfVar/ddi:valrng/ddi:range/@max">
				<xsl:text>&amp;maxY=</xsl:text>
				<xsl:value-of select="$FirstSelfVar/ddi:valrng/ddi:range[1]/@max"/>
			</xsl:if>
			<xsl:for-each select="$participants">
				<xsl:text>&amp;data=</xsl:text>
				<xsl:call-template name="GetScaleValue">
					<xsl:with-param name="scaleName" select="$varGrpScaleID"/>
					<xsl:with-param name="participant" select="."/>
				</xsl:call-template>
			</xsl:for-each>
			<xsl:choose>
				<xsl:when test="$FirstSelfVar">
					<xsl:for-each select="$FirstSelfVar/ddi:catgry[number(ddi:catValu) &gt;= 0]">
						<xsl:sort order="ascending" select="ddi:catValu"/>

						<xsl:text>&amp;labels=</xsl:text>
						<xsl:value-of select="ExsltStrings:URLEncode(normalize-space(ddi:labl))"/>
					</xsl:for-each>
				</xsl:when>
				<xsl:otherwise>
					
				</xsl:otherwise>
			</xsl:choose>
		</xsl:if>
	</xsl:template>
	
	

	<xsl:template match="nassess:scale[@type='gradientGraph'][@refid]">
		<xsl:variable name="varGrpScaleID" select="@refid"/>
		<xsl:variable name="varGrpScale" select="$codebook/ddi:dataDscr/ddi:varGrp[@type='analysis'][@ID=$varGrpScaleID]"/>
		
		
		<xsl:variable name="FirstVarIDInGrp">
			<xsl:call-template name="GetFirstVarIDInGrp">
				<xsl:with-param name="varGrp" select="$varGrpScale"/>
			</xsl:call-template>
		</xsl:variable>
		<xsl:variable name="FirstSelfVar" select="$codebook/ddi:dataDscr/ddi:var[@ID=$FirstVarIDInGrp]"/>
		
		<xsl:variable name="legendID" select="concat(@refid,'_legend')"/>
		
		<xsl:if test="not(@label='hide' or @legend='only')">
			<xsl:apply-templates select='.' mode='label'>
				<xsl:with-param name="varGrpScale" select="$varGrpScale"/>
				<xsl:with-param name="FirstSelfVar" select="$FirstSelfVar"/>
			</xsl:apply-templates>
		</xsl:if>
		
		<xsl:if test="not(@legend='only')">
			<xsl:apply-templates select='.' mode='graph'>
				<xsl:with-param name="varGrpScale" select="$varGrpScale"/>
				<xsl:with-param name="varGrpScaleID" select="$varGrpScaleID"/>
				<xsl:with-param name="FirstSelfVar" select="$FirstSelfVar"/>
				<xsl:with-param name="legendID" select="$legendID"/>
			</xsl:apply-templates>
		</xsl:if>
		
		<xsl:if test="not(@legend='hide')">
			<xsl:apply-templates select='.' mode='legend'>
				<xsl:with-param name="legendID" select="$legendID"/>
			</xsl:apply-templates>
		</xsl:if>
	</xsl:template>
	<xsl:template match="nassess:scale[@type='gradientGraph'][@legend='only']">
		<xsl:apply-templates select='.' mode='legend'/>
	</xsl:template>

</xsl:stylesheet>
