<?xml version="1.0" encoding="UTF-8" ?>
<xsl:stylesheet version="1.0" 
				xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
				xmlns:nassess="http://nassess.byu.edu/report"
				xmlns:culture="http://nassess.byu.edu/culture"
				xmlns:msxsl="urn:schemas-microsoft-com:xslt"
				xmlns:ddi="http://www.icpsr.umich.edu/DDI"
				xmlns="http://www.w3.org/1999/xhtml" 
				xmlns:ExsltStrings="http://fhss.byu.edu/exslt/strings"
				exclude-result-prefixes="ExsltStrings xsl nassess ddi">

<xsl:import href="project://NAssess.Core/Engines/Reporting/xslt/global.xslt"/>
<xsl:import href="project://NAssess.Core/Engines/Reporting/xslt/scale.value.xslt"/>

<xsl:param name="graphURL"/>
<xsl:param name="graphLegendURL"/>
<xsl:param name="graphLabelsURL"/>

	<xsl:template name="GetGraphURL">
		<xsl:param name="GraphStyle"/>
		<xsl:param name="varGrpScale"/>
		<xsl:param name="varGrpScaleID"/>
		<xsl:param name="FirstSelfVar"/>
		<xsl:param name="scale"/>

		<xsl:if test="$graphURL">
			<xsl:value-of select="$graphURL"/>
			<xsl:text>title=</xsl:text><xsl:value-of select="ExsltStrings:URLEncode(normalize-space($varGrpScale/ddi:labl))"/>
			<xsl:text>&amp;style=</xsl:text><xsl:value-of select="$GraphStyle"/>
			<xsl:text>&amp;gradient=true</xsl:text>
			<!-- use the scale's first variable's range for response values to determine MaxY variable -->
			<xsl:if test="$FirstSelfVar/ddi:valrng/ddi:range/@max">
				<xsl:text>&amp;maxY=</xsl:text><xsl:value-of select="$FirstSelfVar/ddi:valrng/ddi:range[1]/@max"/>
			</xsl:if>
			<xsl:if test="$scale/@width">&amp;width=<xsl:value-of select="$scale/@width"/></xsl:if>
			<xsl:if test="$scale/@height">&amp;height=<xsl:value-of select="$scale/@height"/></xsl:if>
			
			<xsl:for-each select="$participants">
				<xsl:text>&amp;scales=</xsl:text>
				<xsl:call-template name="GetScaleValue">
					<xsl:with-param name="scaleName" select="$varGrpScaleID"/>
					<xsl:with-param name="participant" select="."/>
				</xsl:call-template>
				
				<!-- Consider adding cutoff colors to the graph -->
				<xsl:if test="not($scale/@cutoffs='hide')">
					<xsl:variable name="greenCutoff">
						<xsl:choose>
							<!-- Is there a gender-specific match? -->
							<xsl:when test="$varGrpScale/ddi:concept/@vocab=concat(current()/@Gender,'G')">
								<xsl:value-of select="$varGrpScale/ddi:concept[@vocab=concat(current()/@Gender,'G')]"/>
							</xsl:when>
							<!-- Is there a gender-neutral match? -->
							<xsl:when test="$varGrpScale/ddi:concept/@vocab='G'">
								<xsl:value-of select="$varGrpScale/ddi:concept[@vocab='G']"/>
							</xsl:when>
						</xsl:choose>
					</xsl:variable>
					<xsl:variable name="redCutoff">
						<xsl:choose>
							<!-- Is there a gender-specific match? -->
							<xsl:when test="$varGrpScale/ddi:concept/@vocab=concat(current()/@Gender,'R')">
								<xsl:value-of select="$varGrpScale/ddi:concept[@vocab=concat(current()/@Gender,'R')]"/>
							</xsl:when>
							<!-- Is there a gender-neutral match? -->
							<xsl:when test="$varGrpScale/ddi:concept/@vocab='R'">
								<xsl:value-of select="$varGrpScale/ddi:concept[@vocab='R']"/>
							</xsl:when>
						</xsl:choose>
					</xsl:variable>
					<xsl:text>g</xsl:text>
					<xsl:value-of select="$greenCutoff"/>
					<xsl:text>r</xsl:text>
					<xsl:value-of select="$redCutoff"/>
				</xsl:if>
			</xsl:for-each>
		</xsl:if>
	</xsl:template>
	<xsl:template name="GetLabelURL">
		<xsl:param name="GraphStyle"/>
		<xsl:param name="varGrpScale"/>
		<xsl:param name="FirstSelfVar"/>
		<xsl:param name="scale"/>

		<xsl:if test="$graphLabelsURL">
			<xsl:value-of select="$graphLabelsURL"/>
			<xsl:text>style=</xsl:text><xsl:value-of select="$GraphStyle"/>
			<xsl:if test="$scale/@height">&amp;height=<xsl:value-of select="$scale/@height"/></xsl:if>
			<!-- Only display those labels associated with a value of zero or greater, so that 
					"Does not apply" answers that are encoded -1 do not show up -->
			<xsl:for-each select="$FirstSelfVar/ddi:catgry[number(ddi:catValu) &gt;= 0]">
				<xsl:sort order="ascending" select="ddi:catValu"/>

				<xsl:text>&amp;labels=</xsl:text>
				<xsl:value-of select="ExsltStrings:URLEncode(normalize-space(ddi:labl))"/>
			</xsl:for-each>
		</xsl:if>
	</xsl:template>
	<xsl:template name="GetLegendURL">
		<xsl:if test="$graphLegendURL">
			<xsl:value-of select="$graphLegendURL"/>
			<xsl:text>title=</xsl:text>
			<xsl:value-of select="ExsltStrings:URLEncode(culture:GetResourceStringXSLT('GraphLegend'))"/>
			
			<xsl:for-each select="$participants">
				<xsl:text>&amp;labels=</xsl:text>
				<xsl:value-of select="ExsltStrings:URLEncode(@FriendlyName)"/>
			</xsl:for-each>
		</xsl:if>
	</xsl:template>

	<xsl:template name="GetFirstVarIDInGrp">
		<xsl:param name="varGrp"/>
		<xsl:choose>
			<xsl:when test="$varGrp/@var">
				<xsl:value-of select="ExsltStrings:tokenize($varGrp/@var,' ')[1]"/>
			</xsl:when>
			<xsl:when test="$varGrp/@varGrp">				
				<xsl:variable name="IDofNextVarGrp" select="ExsltStrings:tokenize($varGrp/@varGrp,' ')[1]"/>
				<xsl:call-template name="GetFirstVarIDInGrp">
					<xsl:with-param name="varGrp" select="$varGrp/../ddi:varGrp[@ID=$IDofNextVarGrp]"/>
				</xsl:call-template>
			</xsl:when>
		</xsl:choose>
	</xsl:template>

	<xsl:template match="nassess:scale[@type='bargraph'][@refid]">
		<xsl:variable name="varGrpScaleID" select="@refid"/>
		<xsl:variable name="varGrpScale" select="$codebook/ddi:dataDscr/ddi:varGrp[@type='analysis'][@ID=$varGrpScaleID]"/>
		
		<xsl:variable name="GraphStyle">
			<xsl:choose>
				<xsl:when test="$varGrpScale/ddi:defntn">
					<xsl:value-of select="$varGrpScale/ddi:defntn"/>
				</xsl:when>
				<xsl:otherwise>
					<xsl:text>proportional</xsl:text>
				</xsl:otherwise>
			</xsl:choose>
		</xsl:variable>
		
		<xsl:variable name="FirstVarIDInGrp">
			<xsl:call-template name="GetFirstVarIDInGrp">
				<xsl:with-param name="varGrp" select="$varGrpScale"/>
			</xsl:call-template>
		</xsl:variable>
		<xsl:variable name="FirstSelfVar" select="$codebook/ddi:dataDscr/ddi:var[@ID=$FirstVarIDInGrp]"/>
		
		<xsl:variable name="legendID" select="concat(@refid,'_legend')"/>
		
		<xsl:if test="not(@label='hide' or @legend='only')">
			<xsl:apply-templates select='.' mode='label'>
				<xsl:with-param name="GraphStyle" select="$GraphStyle"/>
				<xsl:with-param name="varGrpScale" select="$varGrpScale"/>
				<xsl:with-param name="FirstSelfVar" select="$FirstSelfVar"/>
			</xsl:apply-templates>
		</xsl:if>
		
		<xsl:if test="not(@legend='only')">
			<xsl:apply-templates select='.' mode='graph'>
				<xsl:with-param name="GraphStyle" select="$GraphStyle"/>
				<xsl:with-param name="varGrpScale" select="$varGrpScale"/>
				<xsl:with-param name="varGrpScaleID" select="$varGrpScaleID"/>
				<xsl:with-param name="FirstSelfVar" select="$FirstSelfVar"/>
				<xsl:with-param name="legendID" select="$legendID"/>
			</xsl:apply-templates>
		</xsl:if>
		
		<xsl:if test="not(@legend='hide')">
			<xsl:apply-templates select='.' mode='legend'>
				<xsl:with-param name="legendID" select="$legendID"/>
			</xsl:apply-templates>
		</xsl:if>
	</xsl:template>
	<xsl:template match="nassess:scale[@type='bargraph'][@legend='only']">
		<xsl:apply-templates select='.' mode='legend'/>
	</xsl:template>

</xsl:stylesheet>
