<?xml version="1.0" encoding="UTF-8" ?>
<xsl:stylesheet version="1.0" 
				xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
				xmlns:nassess="http://nassess.byu.edu/report"
				xmlns:ddi="http://www.icpsr.umich.edu/DDI"
				xmlns="http://www.w3.org/1999/xhtml" 
				xmlns:ExsltStrings="http://fhss.byu.edu/exslt/strings"
				exclude-result-prefixes="ExsltStrings xsl nassess ddi">

<xsl:import href="project://NAssess.Core/Engines/Reporting/xslt/global.xslt"/>
<xsl:import href="project://NAssess.Core/Engines/Reporting/xslt/value.xslt"/>

	<xsl:template match="nassess:scale[@type='total'][@refid][@category]">
		<xsl:variable name="participant" select="$participants[position()=current()/@participant]" />
		<xsl:variable name="category" select="@category" />
		<xsl:variable name="scaleID" select="@refid" />
		<xsl:variable name="scale" select="$codebook/ddi:dataDscr/ddi:varGrp[@ID=$scaleID]"/>
		
		<xsl:variable name="lengthincrementor">
			<xsl:apply-templates select="$scale" mode="ScaleRecurse">
				<xsl:with-param name="participant" select="$participant" />
				<xsl:with-param name="category" select="$category" />
			</xsl:apply-templates>
		</xsl:variable>
		<xsl:value-of select="string-length($lengthincrementor)"/>
	</xsl:template>

	<!-- Stop drilling down when we hit the last varGrp, or when we hit a green/red specification -->
	<xsl:template match="ddi:varGrp[not(ddi:concept)][@varGrp]" mode="ScaleRecurse">
		<xsl:param name="participant" />
		<xsl:param name="category" />
		
		<xsl:variable name="subScaleIDs" select="ExsltStrings:tokenize(@varGrp,' ')" />
		<xsl:variable name="subScales" select="$codebook/ddi:dataDscr/ddi:varGrp[@ID=$subScaleIDs]"/>
		<xsl:apply-templates select="$subScales" mode="ScaleRecurse">
			<xsl:with-param name="participant" select="$participant" />
			<xsl:with-param name="category" select="$category" />
		</xsl:apply-templates>
	</xsl:template>
	
	<!-- If there is a red/green spec for the scale we are at, do the work -->
	<xsl:template match="ddi:varGrp[ddi:concept]" mode="ScaleRecurse">
		<xsl:param name="participant" />
		<xsl:param name="category" />

		<xsl:variable name="greenCutoff">
			<xsl:choose>
				<!-- Is there a gender-specific match? -->
				<xsl:when test="ddi:concept/@vocab=concat($participant/@Gender,'G')">
					<xsl:value-of select="number(ddi:concept[@vocab=concat($participant/@Gender,'G')])"/>
				</xsl:when>
				<!-- Is there a gender-neutral match? -->
				<xsl:when test="ddi:concept/@vocab='G'">
					<xsl:value-of select="number(ddi:concept[@vocab='G'])"/>
				</xsl:when>
			</xsl:choose>
		</xsl:variable>
		<xsl:variable name="redCutoff">
			<xsl:choose>
				<!-- Is there a gender-specific match? -->
				<xsl:when test="ddi:concept/@vocab=concat($participant/@Gender,'R')">
					<xsl:value-of select="number(ddi:concept[@vocab=concat($participant/@Gender,'R')])"/>
				</xsl:when>
				<!-- Is there a gender-neutral match? -->
				<xsl:when test="ddi:concept/@vocab='R'">
					<xsl:value-of select="number(ddi:concept[@vocab='R'])"/>
				</xsl:when>
			</xsl:choose>
		</xsl:variable>
		<xsl:variable name="StrengthIsAtLowEnd" select="$greenCutoff &lt; $redCutoff"/>

		<xsl:variable name="value">
			<xsl:call-template name="GetScaleValue">
				<xsl:with-param name="participant" select="$participant"/>
				<xsl:with-param name="scaleName" select="@ID"/>
			</xsl:call-template>
		</xsl:variable>

		<xsl:choose>
			<xsl:when test="$category='green'">
				<xsl:if test="($StrengthIsAtLowEnd and $value &lt;= $greenCutoff) or (not($StrengthIsAtLowEnd) and $value &gt;= $greenCutoff)">
					<xsl:text>I</xsl:text>
				</xsl:if>
			</xsl:when>
			<xsl:when test="$category='red'">
				<xsl:if test="($StrengthIsAtLowEnd and $value &gt;= $redCutoff) or (not($StrengthIsAtLowEnd) and $value &lt;= $redCutoff)">
					<xsl:text>I</xsl:text>
				</xsl:if>
			</xsl:when>
		</xsl:choose>
	</xsl:template>
	
</xsl:stylesheet>
