<?xml version="1.0" encoding="UTF-8" ?>
<xsl:stylesheet version="1.0" 
				xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
				xmlns:nassess="http://nassess.byu.edu/report"
				xmlns:ddi="http://www.icpsr.umich.edu/DDI"
				xmlns="http://www.w3.org/1999/xhtml" 
				xmlns:ExsltStrings="http://fhss.byu.edu/exslt/strings"
				exclude-result-prefixes="ExsltStrings xsl ddi nassess">

<xsl:import href="project://NAssess.Core/Engines/Reporting/xslt/global.xslt"/>

	<!-- Displaying variable value for first or specified participant -->
	<xsl:template match="nassess:value[@var]">
		<xsl:variable name="varName" select="@var"/>

		<xsl:call-template name="GetValue">
			<xsl:with-param name="varName" select="$varName"/>
			<xsl:with-param name="participant" select="$participants[position() = current()/@participant]"/>
		</xsl:call-template>
	</xsl:template>
	
	<!-- Display variable within a <for each='participant'> loop -->
	<xsl:template match="nassess:value[@var][ancestor::nassess:for[@each='participant']]">
		<xsl:param name="context"/>
		<xsl:variable name="varName" select="@var"/>
	
		<xsl:call-template name="GetValue">
			<xsl:with-param name="varName" select="$varName"/>
			<xsl:with-param name="participant" select="$context"/>
		</xsl:call-template>
	</xsl:template>
	
	<xsl:template name="GetValue">
		<xsl:param name="participant" select="$participants[1]" />
		<xsl:param name="evaluation" />  <!-- reserved for later use -->
		<xsl:param name="codeBook" />  <!-- reserved for later use -->
		<xsl:param name="varName" />

		<!-- get absolute value of response -->
		<xsl:variable name="varValue" select="$participant/evaluation/responses/@*[name() = $varName]"/>
		<!-- look up whether this value has a label -->
		<xsl:variable name="varValueLabel" select="normalize-space($codebook/ddi:dataDscr/ddi:var[@name=$varName]/ddi:catgry[normalize-space(ddi:catValu)=$varValue]/ddi:labl)"/>
		
		<!-- If a label was available, display that.  Otherwise, display the actual value. -->
		<xsl:choose>
			<xsl:when test="$varValueLabel">
				<xsl:value-of select="$varValueLabel"/>
			</xsl:when>
			<xsl:otherwise>
				<xsl:value-of select="$varValue"/>
			</xsl:otherwise>
		</xsl:choose>		
	</xsl:template>
</xsl:stylesheet>