using System;
using System.Collections.Generic;
using System.Text;

using Iesi.Collections;
using MyNHibernateContrib.TwoWayCollections;

namespace NAssess.Core.FollowUp
{
	public class Incentive 
		: IParentReferencingNode<Incentive, EventTracker>,
		IParentReferencingNode<Incentive, IncentiveCollection>
	{
		private int id;

		public int Id
		{
			get { return id; }
			private set { id = value; }
		}
		private IncentiveCollection pool;
		/// <summary>
		/// The pool that this incentive belongs to.
		/// </summary>
		public virtual IncentiveCollection Pool
		{
			get { return pool; }
			set { pool = value; }
		}
		private EventTracker eventTracker;
		/// <summary>
		/// The specific event of one respondent that this incentive has been assigned to.
		/// </summary>
		public virtual EventTracker EventTracker
		{
			get { return eventTracker; }
			private set { eventTracker = value; }
		}


		/// <summary>
		/// Tests whether this and another object are equal in a way that 
		/// will still pass when proxy objects are being used.
		/// </summary>
		public override bool Equals(object obj)
		{
			Incentive other = obj as Incentive;
			if (other == null) return false;
			if (Id == 0 && other.Id == 0)
				return (object)this == other;
			else
				return Id == other.Id;
		}

		public override int GetHashCode()
		{
			if (Id == 0) return base.GetHashCode();
			string stringRepresentation =
				System.Reflection.MethodBase.GetCurrentMethod().DeclaringType.FullName
				+ "#" + Id.ToString();
			return stringRepresentation.GetHashCode();
		}

		#region IParentReferencingNode<Incentive,EventTracker> Members

		EventTracker IParentReferencingNode<Incentive, EventTracker>.Parent
		{
			get { return eventTracker; }
			set { eventTracker = value; }
		}

		#endregion

		#region IParentReferencingNode<Incentive,IncentivePool> Members

		IncentiveCollection IParentReferencingNode<Incentive, IncentiveCollection>.Parent
		{
			get { return Pool; }
			set { Pool = value; }
		}

		#endregion
	}
}
