using System;
using System.Collections.Generic;
using System.Text;

using MyNHibernateContrib.TwoWayCollections;

namespace NAssess.Core.FollowUp
{
	public class InvitationEmail : Email,
		IParentReferencingNode<InvitationEmail, Study>
	{
		private Study study;

		public virtual Study Study
		{
			get { return study; }
			private set { study = value; }
		}

		/// <summary>
		/// Gets the name of this incentive pool, 
		/// as it appears as a key in the Study.IncentivePools dictionary.
		/// </summary>
		public virtual string Name
		{
			get
			{
				if (Study == null) return null;
				foreach (KeyValuePair<string, InvitationEmail> pair in Study.InvitationEmails)
					if (pair.Value.Equals(this)) return pair.Key;
				throw new ApplicationException("Unable to find email in Study.InvitationEmails dictionary.");
			}
			set
			{
				if (Study == null) throw new ApplicationException("This email must first be associated with a Study.");
				Study study = Study;
				study.InvitationEmails.Remove(Name);
				study.InvitationEmails[value] = this;
			}
		}

		#region IParentReferencingNode<InvitationEmail, Study> Members

		Study IParentReferencingNode<InvitationEmail, Study>.Parent
		{
			get { return study; }
			set { study = value; }
		}

		#endregion
	}
}
