using System;
using System.IO;
using System.Text.RegularExpressions;
using System.Web;
using System.Web.Caching;
using System.Collections.Specialized;
using System.Collections.Generic;
using System.Globalization;
using System.Threading;

namespace NAssess.Core
{
	/// <summary>
	/// Summary description for Project.
	/// </summary>
	internal static class Project
	{
		internal const string DefaultNamespace = "NAssess.Core";
		internal const bool IsXsltDebuggingEnabled =
#if DEBUG
 true
#else
			false
#endif
;

		/// <summary>
		/// Gets an item from the cache if it is available.
		/// </summary>
		internal static T GetFromCacheIfAvailable<T>(string key)
		{
			if (key == null || key.Length == 0) throw new ArgumentNullException("key");

			HttpContext context = HttpContext.Current;
			if (context == null) return default(T); // no web context available
			return (T)context.Cache[key];
		}
		/// <summary>
		/// Saves an item in the cache, if it is available.
		/// </summary>
		internal static void SaveInCacheIfAvailable<T>(string key, T value)
		{
			if (key == null || key.Length == 0) throw new ArgumentNullException("key");

			HttpContext context = HttpContext.Current;
			if (context == null) return; // no web context available
			if (value != null)
				context.Cache[key] = value;
			else
				context.Cache.Remove(key);
		}

		static Dictionary<string, string> fileExtensionsAndMimeTypes = new Dictionary<string, string>(4, new CaseInsensitiveComparer());
		/// <summary>
		/// Gets the MIME type for a given filename.
		/// </summary>
		internal static string GetMimeType(string fileName)
		{
			return fileExtensionsAndMimeTypes[Path.GetExtension(fileName)];
		}

		static Project()
		{
			fileExtensionsAndMimeTypes.Add("gif", "image/gif");
			fileExtensionsAndMimeTypes.Add("jpg", "image/jpeg");
			fileExtensionsAndMimeTypes.Add("png", "image/png");
			fileExtensionsAndMimeTypes.Add("js", "text/javascript");
		}

		class CaseInsensitiveComparer : System.Collections.CaseInsensitiveComparer, IEqualityComparer<string>
		{
			bool IEqualityComparer<string>.Equals(string x, string y)
			{
				return base.Compare(x, y) == 0;
			}

			int IEqualityComparer<string>.GetHashCode(string obj)
			{
				return obj.GetHashCode();
			}
		}
	}
}
