using System;
using System.Collections.Generic;
using System.Diagnostics;
using NAssess.Core.Evaluating;

namespace NAssess.Core.Reporting
{
	/// <summary>
	/// Summary description for ReportEvaluations.
	/// </summary>
	public class ReportEvaluations
	{
		private ReportParticipant reportParticipant;
		protected IList<Evaluating.Evaluation> Evaluations = new List<Evaluating.Evaluation>();

		internal event EventHandler Changed;
	
		public ReportEvaluations(ReportParticipant parent)
		{
			reportParticipant = parent;
		}

		#region Attributes
		public ReportParticipant ReportParticipant
		{
			get
			{
				return reportParticipant;
			}
			protected set
			{
				reportParticipant = value;
			}
		}
		public Evaluating.Evaluation this[int index]
		{
			get
			{
				return Evaluations[index];
			}
		}
		public int Count
		{
			get
			{
				return Evaluations.Count;
			}
		}
		#endregion

		#region Operations
		public void Attach(Evaluation evaluation)
		{
			if( evaluation == null ) throw new ArgumentNullException("evaluation");
			// Ignore this call if this evaluation is already there
			if( Evaluations.Contains(evaluation) ) return;
			// Make sure this evaluation belongs to the questionnaire in question 
			// (unless questionnaire allows guest evaluations)
			if( !ReportParticipant.ReportParticipants.Report.Assessment.AllowGuestQuestionnaires &&
				evaluation.Questionnaire.Id != ReportParticipant.ReportParticipants.Report.Questionnaire.Id )
				throw new ArgumentOutOfRangeException("evaluation", evaluation.Questionnaire.Name, "The evaluation must be of the same type of questionnaire as this assessment.");
			// Make sure we don't go over the evaluation count per participant limit that is part of this assessment
			if (Evaluations.Count + 1 > ReportParticipant.ReportParticipants.Report.Assessment.MaxEvalsPerParticipant)
				throw new TooManyEvaluationsPerParticipantException();

			// Go ahead and add the evaluation
			Evaluations.Add( evaluation );
			evaluation.Responses.Changed += new EvaluationResponses.ResponsesChangedEventHandler(Responses_Changed);

			OnChanged();
		}

		void Responses_Changed(Evaluation evaluation, string[] variableNames)
		{
			OnChanged();
		}
		#endregion
		#region Events
		protected virtual void OnChanged()
		{
			// use thread-safe way of firing this event
			EventHandler changed = Changed;
			if( changed != null ) changed(this, null);
		}
		#endregion
		#region Enumerator
		public Enumerator GetEnumerator()
		{
			return new Enumerator(this);
		}
		public class Enumerator
		{
			int position = -1;
			ReportEvaluations parent;
			protected internal Enumerator( ReportEvaluations parent )
			{
				this.parent = parent;
			}
			public bool MoveNext()
			{
				return ++position < parent.Evaluations.Count;
			}
			public Evaluating.Evaluation Current
			{
				get 
				{
					Trace.Assert( position < parent.Evaluations.Count, 
						"This enumerator is being called incorrectly at the end of the list.");
					return (Evaluating.Evaluation) parent.Evaluations[position];
				}
			}

		}
		#endregion

	}
}
