using System;
using MetaData;

namespace NAssess.Core.Reporting
{
	/// <summary>
	/// Summary description for ReportParticipant.
	/// </summary>
	public class ReportParticipant
	{
		private ReportParticipants reportParticipants;
		private string name;
		private Demographics.GenderType gender = Demographics.GenderType.Unknown;
		private ReportEvaluations evaluations;

		internal event EventHandler Changed;

		protected internal ReportParticipant(ReportParticipants parent, string name, Demographics.GenderType gender)
		{
			ReportParticipants = parent;
			this.name = name;
			this.gender = gender;
			Evaluations = new ReportEvaluations(this);
			Evaluations.Changed += new EventHandler(Evaluations_Changed);
		}

		#region Attributes
		public ReportEvaluations Evaluations
		{
			get { return evaluations; }
			private set { evaluations = value; }
		}
		public ReportParticipants ReportParticipants
		{
			get { return reportParticipants; }
			private set { reportParticipants = value; }
		}
		public string Name
		{
			get
			{
				return name;
			}
		}
		public Demographics.GenderType Gender
		{
			get
			{
				return gender;
			}
			set
			{
				gender = value;
			}
		}
		#endregion

		public override bool Equals(object obj)
		{
			if (obj == null) return false;
			string other = obj as string;
			if (other != null)
				return Name == other;
			else
				return Name == ((ReportParticipant)obj).Name;
		}

		public override int GetHashCode()
		{
			return Name.GetHashCode();
		}

		public override string ToString()
		{
			return Name;
		}

		private void Evaluations_Changed(object sender, EventArgs e)
		{
			// propogate change event upward
			OnChanged();
		}

		#region Events
		protected virtual void OnChanged()
		{
			if (Changed != null) Changed(this, null);
		}
		#endregion
	}
}
