using System;
using System.Collections;
using System.ComponentModel;
using System.Web.UI;

namespace NAssess.Core.Web
{
	/// <summary>
	/// Summary description for LinkedReportUrl.
	/// </summary>
	public sealed class LinkedReportUrl : IStateManager
	{
		public LinkedReportUrl()
		{
		}

		public LinkedReportUrl(int assessmentId, string assessmentName, string urlTemplate)
		{
			AssessmentId = assessmentId;
			AssessmentName = assessmentName;
			UrlTemplate = urlTemplate;
		}

		[NotifyParentProperty(true)] public int AssessmentId
		{
			get
			{
				return (int)ViewState["AssessmentId"];
			}
			set
			{
				if (value <= 0)
					throw new ArgumentOutOfRangeException("AssessmentId");
				ViewState["AssessmentId"] = value;
			}
		}

		[NotifyParentProperty(true)] public string AssessmentName
		{
			get
			{
				return (string) ViewState["AssessmentName"];
			}
			set
			{
				if( value == null || value.Length == 0 ) 
					throw new ArgumentNullException("AssessmentName");
				ViewState["AssessmentName"] = value;
			}
		}

		[NotifyParentProperty(true)] public string UrlTemplate
		{
			get
			{
				return (string) ViewState["UrlTemplate"];
			}
			set
			{
				if( value == null || value.Length == 0 ) 
					throw new ArgumentNullException("UrlTemplate");
				ViewState["UrlTemplate"] = value;
			}
		}

		/// <summary>
		/// Gets the ViewState for this setting.
		/// </summary>
		[
			Browsable(false),
			DesignerSerializationVisibility(DesignerSerializationVisibility.Hidden)
		]
		private StateBag ViewState 
		{
			get 
			{
				if (viewState == null) 
				{ 
					viewState = new StateBag(false);
					if( isTrackingViewState ) ((IStateManager)viewState).TrackViewState();
				}
				return viewState;
			}
		}

		internal void SetDirty() 
		{
			if( viewState != null )
				foreach (string key in viewState.Keys) 
					viewState.SetItemDirty(key, true);
		}

		#region IStateManager Members
		private bool isTrackingViewState;
		private StateBag viewState;

		void IStateManager.TrackViewState()
		{
			isTrackingViewState = true;
			if( viewState != null )
				((IStateManager)viewState).TrackViewState();
		}

		bool IStateManager.IsTrackingViewState
		{
			get
			{
				return isTrackingViewState;
			}
		}

		object IStateManager.SaveViewState()
		{
			if( viewState != null )
				return ((IStateManager)viewState).SaveViewState();
			return null;
		}

		void IStateManager.LoadViewState(object savedState)
		{
			if( savedState != null )
				((IStateManager)ViewState).LoadViewState(savedState);
		}

		#endregion
	}
}
