﻿using System;
using System.Collections.Generic;
using Microsoft.VisualStudio.TestTools.UnitTesting;

using NAssess.Core.FollowUp;

namespace TestNAssess.FollowUp
{
	/// <summary>
	/// This is a test class for NAssess.Core.FollowUp.IncentiveCollection and is intended
	/// to contain all NAssess.Core.FollowUp.IncentiveCollection Unit Tests
	///</summary>
	[TestClass()]
	public class IncentivePoolTest : TestBase
	{
		/// <summary>
		/// A test for LotteryOddsAgainst
		/// </summary>
		[TestMethod()]
		public void LotteryOddsAgainstTest()
		{
			IncentiveCollection target = new IncentiveCollection();
			int val = 100; // odd are 1:100 of winning
			target.LotteryOdds = val;
			Assert.AreEqual(val, target.LotteryOdds, "NAssess.Core.FollowUp.IncentiveCollection.LotteryOddsAgainst was not set correctly.");
		}



		/// <summary>
		/// Tests that LotteryOddsAgainst does not allow a 1:1 odd of winning.
		/// </summary>
		[TestMethod()]
		[ExpectedException(typeof(ArgumentOutOfRangeException))]
		public void LotteryOddsAgainstNotLotteryTest()
		{
			IncentiveCollection target = new IncentiveCollection();
			int val = 1; // not a lottery if odds are 1:1
			target.LotteryOdds = val;
		}

		/// <summary>
		/// Tests that LotteryOddsAgainst does not allow a 1:1 odd of winning.
		/// </summary>
		[TestMethod()]
		[ExpectedException(typeof(ArgumentOutOfRangeException))]
		public void LotteryOddsAgainstRangeTest1()
		{
			IncentiveCollection target = new IncentiveCollection();
			int val = 0; // some nonsensical value
			target.LotteryOdds = val;
		}

		/// <summary>
		/// Tests that LotteryOddsAgainst does not allow a 1:1 odd of winning.
		/// </summary>
		[TestMethod()]
		[ExpectedException(typeof(ArgumentOutOfRangeException))]
		public void LotteryOddsAgainstRangeTest2()
		{
			IncentiveCollection target = new IncentiveCollection();
			int val = -1; // some nonsensical value
			target.LotteryOdds = val;
		}

		[TestMethod()]
		public void IncentivePoolPersistenceTest()
		{
			IncentiveCollection pool = new IncentiveCollection();
			pool.LotteryOdds = 50;
			pool.Email = new IncentiveEmail();

			mgr.Save(pool);
			NAssessDbMgr.EndSession();

			IncentiveCollection pool2 = NAssessDbMgr.Get<IncentiveCollection>(pool.Id);
			if ((object)pool == (object)pool2)
				Assert.Inconclusive("Test no good if they are the same object.");

			Assert.AreEqual(pool.Id, pool2.Id);
			Assert.AreEqual(pool.LotteryOdds, pool2.LotteryOdds);
			Assert.AreEqual(pool.Email, pool2.Email);
		}
	}
}
