﻿using System;
using System.Diagnostics;
using Microsoft.VisualStudio.TestTools.UnitTesting;

using NAssess.Core.FollowUp;

namespace TestNAssess.FollowUp
{
	/// <summary>
	/// This is a test class for NAssess.Core.FollowUp.StudyEvent and is intended
	/// to contain all NAssess.Core.FollowUp.StudyEvent Unit Tests
	/// </summary>
	[TestClass()]
	public class StudyEventTest : TestBase
	{
		[TestMethod]
		public void StudyEventPersistenceTest()
		{
			StudyEvent se = new StudyEvent();
			se.Description = "some description";
			se.MaxInvites = 6;
			se.Repeats = 2;
			se.TimeBetweenInvites = TimeSpan.FromDays(14);
			se.TimeToRespond = TimeSpan.FromDays(14);
			se.WaitTime = TimeSpan.FromDays(365);

			se.ParticipatingIncentives = new IncentiveCollection();
			Incentive iA = new Incentive();
			se.ParticipatingIncentives.Add(iA);
			Incentive iB = new Incentive();
			se.ParticipatingIncentives.Add(iB);

			mgr.Save(se);
			NAssessDbMgr.EndSession();

			StudyEvent se2 = NAssessDbMgr.Get<StudyEvent>(se.Id);
			Debug.Assert((object)se != (object)se2, "Test no good if they are the same object.");
			Assert.AreEqual(se.Description, se2.Description);
			Assert.AreEqual(se.MaxInvites, se2.MaxInvites);
			Assert.AreEqual(se.Repeats, se2.Repeats);
			Assert.AreEqual(se.TimeBetweenInvites, se2.TimeBetweenInvites);
			Assert.AreEqual(se.TimeToRespond, se2.TimeToRespond);
			Assert.AreEqual(se.WaitTime, se2.WaitTime);

			Assert.AreEqual(se.ParticipatingIncentives.Count, se2.ParticipatingIncentives.Count);
			foreach (Incentive i2 in se2.ParticipatingIncentives)
				Assert.IsTrue(i2.Id == iA.Id || i2.Id == iB.Id);
		}

		[TestMethod()]
		[ExpectedException(typeof(ArgumentOutOfRangeException))]
		public void RepeatNegativeTest()
		{
			StudyEvent se = new StudyEvent();
			se.Repeats = -1;
		}
	}
}
