using System;
using System.Collections;
using System.Text;
using System.Reflection;

using NHibernate;
using NHibernate.Cfg;
using NHibernate.Expression;
using NHibernate.Tool.hbm2ddl;

using MyNHibernateContrib.GenericCollections;
using NAssess.Core;
using NAssess.Core.Evaluating;
using NAssess.Core.Reporting;
using NAssess.Core.FollowUp;

namespace TestNAssess
{
	public class NAssessDbMgr : MyNHibernateContrib.DbMgr, INAssessManager
	{
		static NAssessDbMgr()
		{
			InitializeConfiguration += new InitializeConfigurationEventHandler(OnInitializeConfiguration);
		}

		static void OnInitializeConfiguration(Configuration config)
		{
			//config.AddAssembly(typeof(Questionnaire).Assembly);
			config.AddClass(typeof(Questionnaire));
			config.AddClass(typeof(Evaluation));
			config.AddClass(typeof(Assessment));
			config.AddClass(typeof(ReportTemplate));
			config.AddClass(typeof(EventTracker));
			config.AddClass(typeof(EvaluationTracker));
			config.AddClass(typeof(Incentive));
			config.AddClass(typeof(IncentiveCollection));
			config.AddClass(typeof(StudyEvent));
			config.AddClass(typeof(Email));
			config.AddClass(typeof(StockProduct));
			config.AddClass(typeof(Ddi));
			config.AddClass(typeof(FollowUp.FollowUpStudy));
		}

		#region INAssessManager Members

		Assessment INAssessManager.GetAssessment(int assessmentId)
		{
			return NAssessDbMgr.Get<Assessment>(assessmentId);
		}

		Evaluation INAssessManager.GetEvaluation(int evaluationId)
		{
			return NAssessDbMgr.Get<Evaluation>(evaluationId);
		}

		System.Collections.Generic.IEnumerable<Evaluation> INAssessManager.GetDataSetEvaluations(int questionnaireId)
		{
			System.Collections.IList evalIds =
				Session.CreateQuery("select e.Id from Evaluation e where e.IncludeInDataSet = 1 and e.Questionnaire.Id = ?")
				.SetInt32(0, questionnaireId)
				.List();
			foreach (int evalId in evalIds)
			{
				Evaluation eval = Get<Evaluation>(evalId);
				yield return eval;
				Session.Evict(eval);
			}
		}

		void INAssessManager.SaveEvaluation(NAssess.Core.Evaluating.Evaluation evaluation)
		{
			this.Save(evaluation);
		}

		System.Collections.Generic.IEnumerable<Study> INAssessManager.GetStudies()
		{
			return NAssessDbMgr.GetList<Study>();
		}

		Incentive INAssessManager.FindUnassignedIncentive(IncentiveCollection incentivePool)
		{
			System.Collections.IList results = Session
				.CreateCriteria(typeof(Incentive))
				.SetMaxResults(1)
				.Add(new NullExpression("EventTracker"))
				.List();
			if (results.Count > 0)
				return (Incentive)results[0];
			else
				return null;
		}

		public System.Net.Mail.MailAddress GetMailAddressFor(EventTracker eventTracker)
		{
			return new System.Net.Mail.MailAddress("nobody@byu.edu", "Test User");
		}

		#endregion

		public void Save(object o)
		{
			MyNHibernateContrib.DbMgr.Save(o);
		}
	}
}
