﻿using System;
using System.Collections.Generic;
using System.Xml;
using System.Globalization;
using System.Threading;
using Microsoft.VisualStudio.TestTools.UnitTesting;

using NerdBank.Tools;
using NAssess.Core.Evaluating;
using NAssess.Core.Reporting;

namespace TestNAssess.Reporting
{
	/// <summary>
	///This is a test class for NAssess.Core.Reporting.Assessment and is intended
	///to contain all NAssess.Core.Reporting.Assessment Unit Tests
	///</summary>
	[TestClass()]
	public class AssessmentTest : TestBase
	{
        /// <summary>
		/// A test case for Template
		/// </summary>
		[TestMethod()]
		public void TemplateTest()
		{
			Assessment target = new Assessment();
			Assert.IsNull(target.Questionnaire);

			XmlDocument xml = new XmlDocument();
			xml.LoadXml(EmbeddedResources.LoadFileFromAssemblyWithNamespace("/Reporting/report.xml", TestBase.DefaultNamespace));
			ReportTemplate val = new ReportTemplate(xml);

			target.Template = val;

			Assert.AreEqual(val, target.Template, "NAssess.Core.Reporting.Assessment.Template was not set correctly.");
		}

		/// <summary>
		/// A test case for Template
		/// </summary>
		[TestMethod()]
		public void TemplateMulticulturalTest()
		{
			Assessment target = new Assessment();

			XmlDocument xml = new XmlDocument();
			xml.LoadXml(EmbeddedResources.LoadFileFromAssemblyWithNamespace("/Reporting/report.xml", TestBase.DefaultNamespace));
			ReportTemplate val = new ReportTemplate(xml);

			XmlDocument xml2 = new XmlDocument();
			xml2.LoadXml(EmbeddedResources.LoadFileFromAssemblyWithNamespace("/Reporting/report-culture.xml", TestBase.DefaultNamespace));
			ReportTemplate val2 = new ReportTemplate(xml2);

			CultureInfo ci = Thread.CurrentThread.CurrentUICulture;
			try
			{
				target.Template = val;
				Assert.AreEqual(val, target.Template);

				Thread.CurrentThread.CurrentUICulture = CultureInfo.GetCultureInfo("es-MX");
				target.Template = val2;
				Assert.AreEqual(val2, target.Template);

				Thread.CurrentThread.CurrentUICulture = ci;
				Assert.AreEqual(val, target.Template);

				Thread.CurrentThread.CurrentUICulture = CultureInfo.GetCultureInfo("es-MX");
				Assert.AreEqual(val2, target.Template);
			}
			finally
			{
				Thread.CurrentThread.CurrentUICulture = ci;
			}
		}

		[TestMethod()]
		public void DefaultLimitsTest()
		{
			Assessment assessment = new Assessment();
			Assert.IsFalse(assessment.MaxEvalsPerParticipant < 1, "Maximum evaluations per participant is less than one.");
			Assert.IsFalse(assessment.MaxParticipants < 1, "Maximum participants is less thanone.");
		}

		/// <summary>
		///A test case for MinParticipants
		///</summary>
		[TestMethod()]
		public void MinParticipantsTest()
		{
			Assessment target = new Assessment();

			int val = 2;

			target.MaxParticipants = 5; // something higher to allow for raising the minimum
			target.MinParticipants = val;

			Assert.AreEqual(val, target.MinParticipants, "NAssess.Core.Reporting.Assessment.MinParticipants was not set correctly.");
		}

		/// <summary>
		///A test case for MinEvalsPerParticipant
		///</summary>
		[TestMethod()]
		public void MinEvalsPerParticipantTest()
		{
			Assessment target = new Assessment();

			int val = 2;

			target.MaxEvalsPerParticipant = 5; // something higher to allow for raising the minimum
			target.MinEvalsPerParticipant = val;

			Assert.AreEqual(val, target.MinEvalsPerParticipant, "NAssess.Core.Reporting.Assessment.MinEvalsPerParticipant was not set correctly.");
		}

		/// <summary>
		///A test case for MaxParticipants
		///</summary>
		[TestMethod()]
		public void MaxParticipantsTest()
		{
			Assessment target = new Assessment();

			int val = 5;

			target.MaxParticipants = val;

			Assert.AreEqual(val, target.MaxParticipants, "NAssess.Core.Reporting.Assessment.MaxParticipants was not set correctly.");
		}

		/// <summary>
		///A test case for MaxEvalsPerParticipant
		///</summary>
		[TestMethod()]
		public void MaxEvalsPerParticipantTest()
		{
			Assessment target = new Assessment();

			int val = 5;

			target.MaxEvalsPerParticipant = val;


			Assert.AreEqual(val, target.MaxEvalsPerParticipant, "NAssess.Core.Reporting.Assessment.MaxEvalsPerParticipant was not set correctly.");
		}

		/// <summary>
		/// A test case for MaxParticipants
		/// </summary>
		[TestMethod()]
		[ExpectedException(typeof(ArgumentOutOfRangeException))]
		public void MaxParticipantsBelowMinTest()
		{
			Assessment target = new Assessment();
			target.MinParticipants = 2;
			target.MaxParticipants = 1;
		}

		/// <summary>
		/// A test case for MinParticipants
		/// </summary>
		[TestMethod()]
		[ExpectedException(typeof(ArgumentOutOfRangeException))]
		public void MinParticipantsAboveMaxTest()
		{
			Assessment target = new Assessment();
			target.MaxParticipants = 4;
			target.MinParticipants = 6;
		}

		/// <summary>
		/// A test case for MaxEvalsPerParticipant
		/// </summary>
		[TestMethod()]
		[ExpectedException(typeof(ArgumentOutOfRangeException))]
		public void MaxEvalsPerParticipantsBelowMinTest()
		{
			Assessment target = new Assessment();
			target.MinEvalsPerParticipant = 2;
			target.MaxEvalsPerParticipant = 1;
		}

		/// <summary>
		/// A test case for MinEvalsPerParticipant
		/// </summary>
		[TestMethod()]
		[ExpectedException(typeof(ArgumentOutOfRangeException))]
		public void MinEvalsPerParticipantsAboveMaxTest()
		{
			Assessment target = new Assessment();
			target.MaxEvalsPerParticipant = 4;
			target.MinEvalsPerParticipant = 6;
		}

		/// <summary>
		/// A test case for MinParticipants
		/// </summary>
		[TestMethod()]
		[ExpectedException(typeof(ArgumentOutOfRangeException))]
		public void MinParticipantsBelow1Test()
		{
			Assessment target = new Assessment();
			target.MinParticipants = 0;
		}

		/// <summary>
		/// A test case for MinEvalsPerParticipant
		/// </summary>
		[TestMethod()]
		[ExpectedException(typeof(ArgumentOutOfRangeException))]
		public void MinEvalsBelow1Test()
		{
			Assessment target = new Assessment();
			target.MinEvalsPerParticipant = 0;
		}

		/// <summary>
		///A test case for ProduceReport ()
		///</summary>
		[TestMethod()]
		[ExpectedException(typeof(InvalidOperationException))]
		public void ProduceReportWithoutTemplateTest()
		{
			Assessment target = new Assessment();
			Questionnaire q = new Questionnaire();
			q.Assessments.Add(target);
			target.ProduceReport();
		}

		/// <summary>
		///A test case for ProduceReport ()
		///</summary>
		[TestMethod()]
		[ExpectedException(typeof(InvalidOperationException))]
		public void ProduceReportWithoutQuestionnaireTest()
		{
			XmlDocument xml = new XmlDocument();
			xml.LoadXml(EmbeddedResources.LoadFileFromAssemblyWithNamespace("/Reporting/report.xml", TestBase.DefaultNamespace));
			ReportTemplate template = new ReportTemplate(xml);

			Assessment target = new Assessment();
			target.Template = template;

			target.ProduceReport();
		}

		/// <summary>
		///A test case for ProduceReport ()
		///</summary>
		[TestMethod()]
		public void ProduceReportTest()
		{
			XmlDocument xml = new XmlDocument();
			xml.LoadXml(EmbeddedResources.LoadFileFromAssemblyWithNamespace("/Reporting/report.xml", TestBase.DefaultNamespace));
			ReportTemplate template = new ReportTemplate(xml);

			Assessment assessment = new Assessment();
			assessment.Name = "test assessment";
			assessment.Template = template;

			Questionnaire q = new Questionnaire();
			q.Assessments.Add(assessment);

			Report actual;
			actual = assessment.ProduceReport();
			Assert.IsNotNull(actual);
		}

		[TestMethod()]
		public void AssessmentPersistanceTest()
		{
			Assessment assessment = new Assessment();
			assessment.Name = "some name";
			assessment.Description = "some description";
			assessment.PrimaryCulture = CultureInfo.GetCultureInfo("es-MX");
			assessment.AllowGuestQuestionnaires = true;
			assessment.MaxParticipants = 3;
			assessment.MaxEvalsPerParticipant = 5;

			XmlDocument xml = new XmlDocument();
			xml.LoadXml(EmbeddedResources.LoadFileFromAssemblyWithNamespace("/Reporting/report.xml", TestBase.DefaultNamespace));
			ReportTemplate template = new ReportTemplate(xml);
			assessment.Template = template;

			mgr.Save(assessment);
			assessment = null;
            NAssessDbMgr.EndSession();

            IList<Assessment> list = NAssessDbMgr.GetList<Assessment>();
			Assert.AreEqual(1, list.Count);
			assessment = list[0];
			Assert.AreEqual("some name", assessment.Name);
			Assert.AreEqual("some description", assessment.Description);
			Assert.AreEqual(true, assessment.AllowGuestQuestionnaires);
			Assert.AreEqual(3, assessment.MaxParticipants);
			Assert.AreEqual(5, assessment.MaxEvalsPerParticipant);
			Assert.AreEqual(CultureInfo.GetCultureInfo("es-MX"), assessment.PrimaryCulture);
			Assert.IsNotNull(assessment.Template, "The active template was not properly persisted.");
			Assert.AreEqual(template.Xml.OuterXml, assessment.Template.Xml.OuterXml);
		}
	}
}
