using System;
using System.Collections.Generic;
using System.Xml;
using System.Xml.XPath;
using Microsoft.VisualStudio.TestTools.UnitTesting;

namespace TestNAssess
{
	public class TestBase
	{
		protected TestBase()
		{
		}

        protected NAssessDbMgr mgr = new NAssessDbMgr();

        static TestBase()
        {
            log4net.Config.DOMConfigurator.Configure(); // get log4net to look at .config file

            NAssessDbMgr.OpeningSession += new NAssessDbMgr.OpeningSessionEventHandler(
                delegate
                {
                    if (!NAssessDbMgr.RecentlyConstructed)
                        NAssessDbMgr.ConstructDatabase();
                });
        }

        [TestCleanup()]
        public virtual void Cleanup()
        {
			try
			{
				if (NAssessDbMgr.IsSessionActive)
					NAssessDbMgr.EndSession();
			}
			catch
			{
				NAssessDbMgr.Rollback();
				throw;
			}
			finally
			{
				if (NAssessDbMgr.RecentlyConstructed)
					NAssessDbMgr.DestructDatabase();
			}
        }

        private TestContext testContextInstance;
        /// <summary>
        /// Gets or sets the test context which provides
        /// information about and functionality for the current test run.
        /// </summary>
        public TestContext TestContext
        {
            get { return testContextInstance; }
            set { testContextInstance = value; }
        }

        internal const string DefaultNamespace = "TestNAssess";
		public const string GoodName = "__TESTONLY_DELETEME";
		public const string DisposableName = "__TESTONLY_DELETEME2";
		public const string NamespaceName = "RELATE Institute";
		public const string QuestionnaireName = "RELATE";

		protected void CompareXmlDocs(string xmlExpected, XmlDocument xmlDoc)
		{
			XmlDocument xml2 = new XmlDocument();
			xml2.PreserveWhitespace = true;
			xml2.LoadXml(xmlExpected);
			Assert.AreEqual( xml2.OuterXml, xmlDoc.OuterXml );
		}
		public static T GetOnlyItem<T>(IEnumerable<T> c)
		{
			foreach (T item in c) return item;
			return default(T);
		}
	}
}
